# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-06-02 14:32:40
@LastEditTime: 2020-07-07 16:03:23
@LastEditors: HuangJingCan
@Description: 枚举类
"""

from enum import Enum, unique


class AppBaseRedisKeyType(Enum):
    """
    redis用到的key
    """
    QqAccessToken = "qq_access_token:"  # QQ accessToken
    QqAccessTokenLock = "qq_access_token_lock:"  # QQ accessToken
    WxAccessToken = "wx_access_token:"  # QQ accessToken
    WxAccessTokenLock = "wx_access_token_lock:"  # QQ accessToken
    UserToken = "pt_app_user_token:"
    ThirdToken = "pt_app_third_token:"
    UserRefreshToken = "pt_app_user_refresh_token:"
    ThirdRefreshToken = "pt_app_third_refresh_token:"
    InviteUserToken = "pt_invite_user_token"  # 用户邀请码
    InviteTokenUser = "pt_invite_token_user"  # 用户邀请码


class RedisKeyType(Enum):
    """
    redis用到的key
    """
    IdWorkKey = "pt_id_generator"  # ID生成器key值
    TelephoneCode = "pt_app_telephone_code:"  # 手机验证码
    PhoneCode = "pt_app_phone_code:"  # 手机验证码，新版
    TelephoneReq = "pt_app_telephone_req:"  # 手机验证码请求
    TelephoneLimit = "pt_app_telephone_limit:"  # 手机验证码请求限制
    SystemGiveDoll = "pt_system_give_doll"  # 系统赠送娃娃
    PtUserRemainTime = "pt_user_remain_time"  # 用户留存时间
    PtUserNotifyNum = "pt_user_notify_num"  # 用户通知数量

    BaseInfoCache = "pt_base_info_cache"  # 基础信息缓存
    AdConfigCache = "pt_ad_config_cache"  # 广告配置缓存
    PtDollConfigCache = "pt_doll_config_cache"  # 娃娃游戏配置信息缓存
    PtUserFansCache = "pt_user_fans_cache"  # 用户粉丝信息缓存
    PtUserFollowCache = "pt_user_follow_cache"  # 用户关注信息缓存
    PtProductCategory = "pt_product_category"  # 产品分类信息缓存
    PtSearchStatisticsLog = "pt_search_statistics_log"  # 查询统计信息缓存
    PtDictInfo = "pt_dict_info"  # 字典信息表
    PtClientVersion = "pt_client_version"  # 客户端更新信息缓存
    PtDollInfo = "pt_doll_info"  # 娃娃信息缓存

    PtDollIncr = "pt_doll_incr"  # 娃娃领取数量，迁移时需要同步数据
    PtDollClothIncr = "pt_doll_cloth_incr"  # 娃娃服饰领取数量，迁移时需要同步数据


class OperationType(Enum):
    """
    @description: 用户操作日志类型
    """
    add = 1
    update = 2
    delete = 3


class ThirdChannelType(Enum):
    """
    第三方登录类型
    """
    NoSdk = 0  # noSdk登录
    QqMini = 1  # QQ小程序登录
    WxMini = 2  # 微信小程序登录
    Phone = 3  # 手机号登录


class UnionChannelType(Enum):
    """
    开放平台类型
    """
    QqConnect = 1  # QQ互联


class AppChannelType(Enum):
    """
    应用类型
    """
    NoSdk = 0  # noSdk
    QqMini = 1  # QQ小程序
    WxMini = 2  # 微信小程序
    iOSApp = 3  # iOS应用
    AndroidApp = 4  # 安卓应用
    H5 = 5  # H5网页


class UserType(Enum):
    """
    用户类型
    """
    Client = 0  # C端用户
    Business = 1  # B端用户


class UserTagType(Enum):
    """
    玩家身份标签
    """
    DollOwner = 1  # 娃名
    DollSeller = 2  # 娃太
    DollPainter = 3  # 画手


class StatisticsOrmType(Enum):
    """
    数据统计
    """
    RegisterUser = 1  # 注册人数
    BindUser = 2  # 绑定手机人数
    BindUserLogin = 3  # 绑定手机号登录
    DollUserLogin = 4  # 有娃用户登录
    ActivateDoll = 5  # 激活娃娃
    InteractComplete = 6  # 互动完成
    StoryEnter = 7  # 体验剧情
    StoryBarrage = 8  # 剧情弹幕
    Talk = 9  # 吐槽
    GraspDoll = 10  # 提起娃娃
    TransferDoll = 11  # 转赠娃娃
    RemainTime = 12  # 停留时间

    ## 产房 1001开始
    FactoryApply = 1001  # 新增申请单
    FactoryOrder = 1002  # 新增订单

    ## 社区 2001开始
    ClubPost = 2001  # 新增动态
    ClubComment = 2002  # 新增评论
    ClubDig = 2003  # 新增点赞

    ## 游戏 3001开始


class UserStatisticsType(Enum):
    """
    用户统计
    """
    DollNum = 1  # 娃娃数量
    ClothNum = 2  # 娃衣数量
    PostNum = 3  # 帖子数量
    CommentNum = 4  # 评论数量，包括评论的评论
    ApplyNum = 5  # 申请单
    QuotationNum = 6  # 报价单
    OrderNum = 7  # 订单


class ActionLogType(Enum):
    """
    操作日志枚举
    """
    # 娃娃
    ActivateDoll = 10001  # 激活娃娃
    DollModifyNick = 10002  # 娃娃改名
    # DollTransfer = 10003  # 转赠成功

    # 互动
    DollInteractRequest = 20001  # 娃娃发起互动请求
    DollInteractResult = 20002  # 是否成功进行互动

    # 剧情
    StoryEnter = 30001  # 进入剧情详情界面
    StoryPass = 30002  # 剧情结局
    StoryBarrage = 30003  # 剧情留言
    StoryUnlock = 30004  # 剧情解锁

    # 玩家概要信息
    Talk = 40001  # 吐槽
    ChiefGetLevelReward = 40002  # 领取等级奖励

    # 用户
    UserFreeze = 50001  # 封号解封
    ModifyNick = 50002  # 修改昵称
    ModifyUserInfo = 50003  # 修改用户信息
    ModifyTelephone = 50004  # 更换手机号
    UserDelete = 50005  # 注销账号

    # 农场
    FarmUnlockField = 60001  # 解锁地块
    FarmAddBuilding = 60002  # 增加建筑
    FarmAddHarvest = 60003  # 收割作物
    FarmMergeBuilding = 60004  # 合并建筑
    FarmGetOrderReward = 60005  # 领取订单奖励
    FarmDeleteBuilding = 60006  # 删除建筑

    # 服饰
    ClothBuy = 70001  # 购买服饰
    ClothChipDecompose = 70002  # 碎片分解

    # 冒险
    AdventureSpeedUp = 80001  # 冒险加速
    AdventureGetRewards = 80002  # 领取奖励
    AdventureSentLostDoll = 80003  # 送走迷路的娃娃
    AdventureCharge = 80004  # 充能

    # 背包
    BagComposeChip = 90001  # 碎片合成

    # 任务
    TaskGetRewards = 100001  # 领取任务奖励

    # gm指令
    GmAddItem = 1000001  # 增加道具

    ## 游戏模块，从 2000001 开始


class DollGetType(Enum):
    """
    娃娃获得类型
    """
    Buy = 1  # 购买获得
    SystemGive = 2  # 系统赠送
    RankingReward = 3  # 新年副本排名奖励
    Transfer = 4  # 转让获得


class DollType(Enum):
    """
    娃娃类型
    """
    Forever = 1  # 永久
    TimeLimit = 2  # 限时


class NoticeMainType(Enum):
    """
    通知主类型
    """
    SystemNotice = 1  # 系统通知
    GameNotice = 2  # 游戏通知


class NoticeType(Enum):
    """
    通知类型
    """
    # 系统
    SystemNotice = 1  # 系统通知

    # 工厂订单
    FactoryOrderApply = 101  # 下单通知
    FactoryOrderQuote = 102  # 报价通知
    FactoryOrderProgress = 103  # 进度更新

    # 游戏
    PlantSteal = 201  # 偷菜通知


class UserNoticeNumType(Enum):
    """
    用户通知数量类型
    """
    ClubDigNum = 1001  # 社区点赞
    ClubCommentNum = 1002  # 社区评论数量


class AssetType(Enum):
    """
    资产类型
    """
    Count = 1  # 次数
    Integral = 2  # 积分
    Gear = 3  # 档位


class AssetSourceType(Enum):
    """
    来源类型
    """
    Buy = 1  # 商场购买
    Task = 2  # 任务
    GmModify = 3  # 手动配置
    Draw = 4  # 抽奖
    BuyBack = 5  # 回购
    Adventure = 6  # 娃娃冒险
    DollLvUp = 7  # 娃娃升级
    BuyCloth = 8  # 购买服饰
    BuyCancel = 9  # 商城购买取消，或超时

    ## 游戏，从 10001 开始


class DictInfoType(Enum):
    """
    字典信息类型
    """
    # 平台相关 10001 开始
    WorkWechatRobotUrl = 10001  # 企业微信机器人地址
    WorkWechatRobotMembers = 10002  # 通知用户列表，工号列表，逗号分隔
    UserDefaultAvatar = 10003  # 用户默认头像
    SystemNoticeAvatar = 10004  # 系统通知默认头像
    UserBackgroundUrl = 10005  # 用户默认背景图
    SearchKeyword = 10006  # 搜索关键词
    SystemNoticeName = 10007  # 系统通知默认名字

    # platform_api 20001 开始

    # game_api，30001 开始


class UserDeleteStatus(Enum):
    Normal = 1  # 正常
    Deleting = 2  # 注销中
    Deleted = 3  # 已注销



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/4/26 16:10
:LastEditTime: 2021/4/26 16:10
:LastEditors: SunYiTan
:Description: QQ小游戏帮助类
"""
import json
import logging
import traceback
from io import BytesIO

import requests
from PIL import Image
from seven_framework import HTTPHelper, TimeHelper

from seven_cmstar_platform.models.enum import AppBaseRedisKeyType
from seven_cmstar_platform.utils.json_util import JsonUtil
from seven_cmstar_platform.utils.redis_util import RedisUtil


class QqMiniHelper:

    @classmethod
    def code_to_session(cls, code: str, app_id: str, app_secret: str):
        """
        QQ验证
        :param code:
        :param app_id:
        :param app_secret:
        :return:
        {
            'errcode': 0,
            'errmsg': '',
            'openid': 'E18DE2D9EE0EDA9CF889A8AF2708xxxx',
            'session_key': 'RzFjaXBDZUl6MTJxxxx',
            'uin': '',
            'unionid': 'UID_B98652A7C90F3C342E8FC4xxxx'
        }

        """
        url = f"https://api.q.qq.com/sns/jscode2session?appid={app_id}" \
              f"&secret={app_secret}&js_code={code}&grant_type=authorization_code"

        response = HTTPHelper.get(url)
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errcode": -1, "errmsg": "接口请求失败"}

    @classmethod
    def get_access_token(cls, app_id: str, app_secret: str):
        """
        获取AccessToken
        :param app_id:
        :param app_secret:
        :return:
        {
            'errcode': 0,
            'access_token': 'AkAKh4iV0RCi1LyXIhgvlRK8PUDEa_y_yj-fnu1xxxx',
            'expires_in': 7200
        }
        """
        url = f"https://api.q.qq.com/api/getToken?grant_type=client_credential&appid={app_id}&secret={app_secret}"

        response = HTTPHelper.get(url)
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errcode": -1, "errmsg": "接口请求失败"}

    @classmethod
    def get_access_token_cache(cls, app_id: str, app_secret: str):
        key = AppBaseRedisKeyType.QqAccessToken.value + app_id
        now = TimeHelper.get_now_timestamp()
        token = ""
        refresh_time = 0
        expires_in = 0

        s = RedisUtil().get(key)
        if s:
            token_info = json.loads(s)
            token = token_info["access_token"]
            refresh_time = token_info["refresh_time"]
            expires_in = token_info["expires_in"]

        if not s or now >= refresh_time + expires_in:
            token = cls.__refresh_access_token(app_id, app_secret)

        return token

    @classmethod
    def __refresh_access_token(cls, app_id: str, app_secret: str):
        lock_key = AppBaseRedisKeyType.QqAccessTokenLock.value + app_id
        redis_util = RedisUtil()
        lock_value = redis_util.acquire_lock_with_timeout(lock_key)
        if lock_value:
            try:
                key = AppBaseRedisKeyType.QqAccessToken.value + app_id
                now = TimeHelper.get_now_timestamp()
                token = ""
                refresh_time = 0
                expires_in = 0

                # 防止重复刷新
                s = RedisUtil().get(key)
                if s:
                    token_info = json.loads(s)
                    token = token_info["access_token"]
                    refresh_time = token_info["refresh_time"]
                    expires_in = token_info["expires_in"]
                if s and now < refresh_time + expires_in and now - refresh_time <= 10:
                    return token

                result = cls.get_access_token(app_id, app_secret)
                if result["errcode"] != 0:
                    logging.getLogger().error(f"get access token fail from qq: {result}")
                    return ""

                token_info = {
                    "access_token": result["access_token"],
                    "expires_in": result["expires_in"],
                    "refresh_time": now
                }

                RedisUtil().set(key, JsonUtil.dumps(token_info))
                return result["access_token"]

            except Exception as e:
                logging.getLogger().error(traceback.format_exc())

            finally:
                redis_util.release_lock(lock_key, lock_value)
        else:
            return ""

    @classmethod
    def msg_sec_check(cls, app_id: str, access_token: str, content: str):
        """
        检查一段文本是否含有违法违规内容
        参考地址：https://q.qq.com/wiki/develop/miniprogram/server/open_port/port_safe.html#security-msgseccheck
        :param app_id:
        :param access_token:
        :param content:
        :return:
        {'errCode': 0, 'errMsg': 'ok'}
        {'errCode': 87014, 'errMsg': 'risky content'}
        """
        url = "https://api.q.qq.com/api/json/security/MsgSecCheck"
        data = {
            "access_token": access_token,
            "appid": app_id,
            "content": content
        }
        headers = {'Content-Type': 'application/json'}

        response = HTTPHelper.post(url, data, headers)
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errCode": -1, "errmsg": "接口请求失败"}

    @classmethod
    def img_sec_check(cls, app_id: str, access_token: str, pic_url: str):
        """
        校验一张图片是否含有违法违规内容。（好像只能检查政治人物的图片，检查不了黄色图片）
        :param app_id:
        :param access_token:
        :param pic_url:
        :return:
        {'errCode': 0, 'errMsg': 'ok'}
        {'errCode': 87014, 'errMsg': 'risky content'}
        """
        r = requests.get(pic_url)

        tmpIm = BytesIO(r.content)
        im = Image.open(tmpIm)
        im_format = im.format.lower()
        file_name = f"{TimeHelper.get_now_timestamp(is_ms=True)}.{im_format}"
        file_format = f"image/{im_format}"

        url = f'https://api.q.qq.com/api/json/security/ImgSecCheck'
        data = {
            "access_token": access_token,
            "appid": app_id
        }
        files = {"media": (file_name, r.content, file_format)}

        response = requests.post(url=url, data=data, files=files)
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errCode": -1, "errmsg": "接口请求失败"}

    @classmethod
    def subscribe_message_send(cls, access_token, template_id, page_path, open_id, content):
        """
        发送订阅消息
        参考文档：https://q.qq.com/wiki/develop/miniprogram/server/open_port/port_subscribe.html
        :param access_token:
        :param mp_template_id:
        :param app_id:
        :param page_path:
        :param open_id:
        :param content:
        :return:
        """
        url = f"https://api.q.qq.com/api/json/subscribe/SendSubscriptionMessage?access_token={access_token}"

        data = {
            "touser": open_id,
            "template_id": template_id,
            "page": page_path,
            "data": content
        }

        response = HTTPHelper.post(url, data, headers={'Content-Type': 'application/json'})
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errcode": -1, "errmsg": "接口请求失败"}



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-01-05 17:16:17
@LastEditTime: 2021-04-21 09:33:51
@LastEditors: SunYiTan
@Description: 
"""
from threading import Thread

from jwt import ExpiredSignatureError, DecodeError
from seven_framework.web_tornado.base_handler.base_api_handler import *

from seven_cmstar_platform.models.asset_base_model import AssetBaseModel
from seven_cmstar_platform.models.db_models.platform.platform_doll_info_model import PlatformDollInfoModel
from seven_cmstar_platform.models.db_models.platform.platform_user_address_model import PlatformUserAddressModel
from seven_cmstar_platform.models.db_models.platform.platform_user_info_model import PlatformUserInfoModel
from seven_cmstar_platform.models.db_models.platform.platform_user_third_auth_model import PlatformUserThirdAuthModel
from seven_cmstar_platform.models.db_models_ex.platform.platform_search_statiscs_log_model_ex import \
    SearchStatisticsLogModelEx
from seven_cmstar_platform.models.db_models_ex.platform.platform_user_follow_model_ex import PlatformUserFollowModelEx
from seven_cmstar_platform.models.db_models_ex.platform.platform_user_statistics_log_model_ex import \
    UserStatisticsLogModelEx
from seven_cmstar_platform.models.db_models_ex.platform.platform_user_statistics_model_ex import UserStatisticsModelEx
from seven_cmstar_platform.models.user_base_model import UserTokenParam, UserBaseInfo
from seven_cmstar_platform.models.enum import AppBaseRedisKeyType, StatisticsOrmType, UserStatisticsType, \
    AppChannelType, UserType
from seven_cmstar_platform.utils.json_util import JsonUtil
from seven_cmstar_platform.utils.jwt_util import JwtUtil
from seven_cmstar_platform.utils.redis_util import RedisUtil


class DollAppBaseHandler(BaseApiHandler):
    """
    :description: 客户端基类
    """

    def options_async(self):
        self.reponse_json_success()

    def check_xsrf_cookie(self):
        return

    def set_default_headers(self):
        allow_origin_list = config.get_value("allow_origin_list")
        origin = self.request.headers.get("Origin")
        if origin:
            if "--production" in sys.argv or "--testing" in sys.argv:
                if origin in allow_origin_list:
                    self.set_header("Access-Control-Allow-Origin", origin)
            else:
                # 本地测试，都通过
                self.set_header("Access-Control-Allow-Origin", origin)

        self.set_header("Access-Control-Allow-Headers",
                        "Origin,X-Requested-With,Content-Type,Accept,User-Token,Manage-ProductID,Manage-PageID,PYCKET_ID")
        self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS")
        self.set_header("Access-Control-Allow-Credentials", "true")

    def prepare_ext(self):
        """
        置于任何请求方法前被调用扩展
        :return:
        :last_editors: SunYiTan
        """
        http_log = config.get_value("http_log")
        if http_log and http_log is True:
            if "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find(
                    "application/json") >= 0 and self.request.body:
                request_params = json.loads(self.request.body)
            else:
                request_params = self.request.arguments

            self.logging_link_info(
                f"--- request: {self.request.path} ---:\n{JsonUtil.dumps(request_params)}")

    def write_error(self, status_code, **kwargs):
        """
        :Description: 重写全局异常事件捕捉
        :last_editors: ChenXiaolei
        """
        self.logger_error.error(
            traceback.format_exc(),
            extra={"extra": {
                "request_code": self.request_code
            }})

        self.set_status(200)
        return self.reponse_json_error("SystemError", "对不起，系统发生错误")

    def http_reponse(self, content, log_extra_dict=None):
        """
        :description: 将字符串返回给客户端
        :param content: 内容字符串
        :param log_extra_dict:
        :return: 将字符串返回给客户端
        :last_editors: SunYiTan
        """
        http_log = config.get_value("http_log")
        if http_log and http_log is True:
            self.logging_link_info(f"--- response: {self.request.path} ---:\n{content}")

        super().http_reponse(content, log_extra_dict)

    def reponse_json_success(self, data=None, desc='调用成功'):
        """
        :description: 通用成功返回json结构
        :param data: 返回结果对象，即为数组，字典
        :param desc: 字符串，服务端返回的错误信息
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        self.reponse_common("0", desc, data)

    def reponse_json_error(self, error_code="", error_message="", data=None, log_type=0):
        """
        :description: 通用错误返回json结构
        :param error_code: 字符串，调用失败（success为false）时，服务端返回的错误码
        :param error_message: 字符串，调用失败（success为false）时，服务端返回的错误信息
        :param data: 返回结果对象，即为数组，字典
        :param log_type: 日志记录类型（0-不记录，1-info，2-error）
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJianYi
        """
        if log_type == 1:
            self.logging_link_info(f"{error_code}\n{error_message}\n{data}\n{self.request}")
        elif log_type == 2:
            self.logging_link_error(f"{error_code}\n{error_message}\n{data}\n{self.request}")

        self.reponse_common(error_code, error_message, data)

    def reponse_common(self, result, desc, data=None, log_extra_dict=None):
        """
        :Description: 输出公共json模型
        :param result: 返回结果标识
        :param desc: 返回结果描述
        :param data: 返回结果对象，即为数组，字典
        :param log_extra_dict:
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: SunYiTan
        """
        template_value = {
            'result': result,
            'desc': desc,
            'data': data}

        self.http_reponse(JsonUtil.dumps(template_value), log_extra_dict)

    def get_param(self, param_name, default="", strip=True):
        """
        :Description: 二次封装获取参数
        :param param_name: 参数名
        :param default: 如果无此参数，则返回默认值
        :param strip:
        :return: 参数值
        :last_editors: SunYiTan
        """
        param_ret = ""

        try:
            if "Content-Type" in self.request.headers and \
                    self.request.headers["Content-type"].lower().find("application/json") >= 0 and \
                    self.request.body:
                json_params = json.loads(self.request.body)
                param_ret = json_params.get(param_name, default)
            else:
                param_ret = self.get_argument(param_name, default, strip=strip)

        except Exception as e:
            self.logging_link_error(traceback.format_exc())

        if param_ret == "":
            param_ret = default

        return param_ret

    def get_int_param(self, param_name, default="", strip=True):
        """
        二次封装获取参数，转换成int类型
        :param param_name: 参数名
        :param default: 如果无此参数，则返回默认值
        :param strip:
        :return: 参数值
        :last_editors: SunYiTan
        """
        param_ret = self.get_param(param_name, default, strip)
        try:
            return int(param_ret)
        except ValueError:
            pass

        return 0

    @staticmethod
    def get_condition_by_id_list(primary_key, id_list=None):
        """
        :description: 根据id_list返回查询条件
        :param primary_key：主键
        :param id_list：id：列表
        :return: 查询条件字符串
        :last_editors: HuangJingCan
        """
        if not id_list:
            return ""
        id_list_str = str(id_list).strip('[').strip(']')
        return f"{primary_key} IN({id_list_str})"

    def create_user_token(self, user_token_param: UserTokenParam):
        """
        生成token
        :param user_id:
        :param third_auth_id:
        :return:
        """
        access_token, expire_time = self.__create_access_token(user_token_param)
        return access_token

    def create_user_token_2(self, user_token_param: UserTokenParam):
        """
        创建用户token
        :param user_token_param:
        :return:
        """
        access_token, expire_time = self.__create_access_token(user_token_param)
        refresh_token, _ = self.__create_refresh_token(user_token_param)

        return {"access_token": access_token, "expire_time": expire_time, "refresh_token": refresh_token}

    def refresh_user_token(self, refresh_token):
        """
        刷新用户token
        :param refresh_token:
        :return:
        """
        jwt_secret = config.get_value("jwt_refresh_secret")

        if not refresh_token:
            return None

        try:
            sub_info = JwtUtil.get_sub_info_from_token(refresh_token, jwt_secret)
            user_token_param = UserTokenParam.dict_2_entity(json.loads(sub_info))
            user_id = user_token_param.user_id
            third_auth_id = user_token_param.third_auth_id

            if user_id > 0:
                # 多平台同时登录，iOS应用和安卓应用不能同时登录
                app_channel = user_token_param.app_channel
                if app_channel == AppChannelType.AndroidApp.value:
                    app_channel = AppChannelType.iOSApp.value

                key = AppBaseRedisKeyType.UserRefreshToken.value + str(user_token_param.user_id) + "_" + str(
                    app_channel)
                old_token = RedisUtil().get(key)
            else:
                key = AppBaseRedisKeyType.ThirdRefreshToken.value + str(third_auth_id)
                old_token = RedisUtil().get(key)
            if not old_token:
                # 已过期
                return None

            if old_token != refresh_token:
                # 在别处登录
                return None

            return self.create_user_token_2(user_token_param)

        except:
            return None

    def __create_access_token(self, user_token_param: UserTokenParam):
        """
        access_token，缓存时间：7天
        :param user_token_param:
        :return:
        """
        jwt_secret = config.get_value("jwt_secret")
        jwt_expire = config.get_value("jwt_expire")

        user_token_param.version = 20210909  # QQ和微信版本分开，可以同时登录
        # 生成没有时间限制的token
        token = JwtUtil.create_token(JsonUtil.dumps(user_token_param), jwt_secret, -1)

        # 刷新缓存
        if user_token_param.user_id > 0:
            # 多平台同时登录，iOS应用和安卓应用不能同时登录
            app_channel = user_token_param.app_channel
            if app_channel == AppChannelType.AndroidApp.value:
                app_channel = AppChannelType.iOSApp.value

            key = AppBaseRedisKeyType.UserToken.value + str(user_token_param.user_id) + "_" + str(app_channel)
            # B端用户
            if user_token_param.user_type == UserType.Business.value:
                key = f"{key}_{user_token_param.user_type}"
            RedisUtil().set(key, token, jwt_expire * 24 * 60 * 60)
        else:
            key = AppBaseRedisKeyType.ThirdToken.value + str(user_token_param.third_auth_id)
            RedisUtil().set(key, token, jwt_expire * 24 * 60 * 60)

        return token, jwt_expire * 24 * 60 * 60

    def __create_refresh_token(self, user_token_param: UserTokenParam):
        """
        refresh_token，缓存时间：30天
        :param user_token_param:
        :return:
        """
        jwt_secret = config.get_value("jwt_refresh_secret")
        jwt_expire = config.get_value("jwt_refresh_expire")

        user_token_param.version = 20210909  # QQ和微信版本分开，可以同时登录
        token = JwtUtil.create_token(JsonUtil.dumps(user_token_param), jwt_secret, jwt_expire + 1)

        # 刷新缓存
        if user_token_param.user_id > 0:
            # 多平台同时登录，iOS应用和安卓应用不能同时登录
            app_channel = user_token_param.app_channel
            if app_channel == AppChannelType.AndroidApp.value:
                app_channel = AppChannelType.iOSApp.value

            key = AppBaseRedisKeyType.UserRefreshToken.value + str(user_token_param.user_id) + "_" + str(app_channel)
            # B端用户
            if user_token_param.user_type == UserType.Business.value:
                key = f"{key}_{user_token_param.user_type}"
            RedisUtil().set(key, token, jwt_expire * 24 * 60 * 60)
        else:
            key = AppBaseRedisKeyType.ThirdRefreshToken.value + str(user_token_param.third_auth_id)
            RedisUtil().set(key, token, jwt_expire * 24 * 60 * 60)

        return token, jwt_expire * 24 * 60 * 60

    def request_header_token(self):
        header_token = {}
        if "User-Token" in self.request.headers:
            req_info_list = str.split(self.request.headers["User-Token"], ";")
            for info in req_info_list:
                kv = str.split(info, "=")
                header_token[kv[0]] = kv[1]
        return header_token

    def get_user_token_param(self) -> UserTokenParam:
        """
        获取请求的玩家信息
        :return:
        """
        header_token = self.request_header_token()
        user_token = header_token.get("UserToken", "")
        jwt_secret = config.get_value("jwt_secret")

        if not user_token:
            return UserTokenParam()

        try:
            sub_info = JwtUtil.get_sub_info_from_token(user_token, jwt_secret)
            return UserTokenParam.dict_2_entity(json.loads(sub_info))
        except:
            return UserTokenParam()

    def get_user_id(self):
        return self.get_user_token_param().user_id

    def get_third_auth_id(self):
        return self.get_user_token_param().third_auth_id

    def get_user_base_info(self, user_id, third_auth_id):
        """
        获取用户基础信息
        :param user_id: 用户唯一id
        :return: UserBaseInfo()
        """
        user_dict = PlatformUserInfoModel().get_dict(where="user_id=%s", params=[user_id])
        if not user_dict:
            return None
        third_auth = PlatformUserThirdAuthModel().get_dict(where="auth_id=%s", params=[third_auth_id])
        if not third_auth:
            return None

        user_base_info = UserBaseInfo()
        user_base_info.user_id = user_dict["user_id"]  # 用户唯一id
        user_base_info.channel = third_auth["last_app_channel"]  # 登录APP渠道标识，0：NoSdk 1：QQ小程序 2：微信小程序，3：iOS应用，4：安卓应用
        user_base_info.app_id = third_auth["app_id"]  # 第三方app_id
        user_base_info.open_id = third_auth["open_id"]  # open_id
        user_base_info.user_nick = user_dict["user_nick"]  # 用户昵称
        user_base_info.avatar = user_dict["avatar"]  # 用户头像
        return user_base_info.__dict__

    def get_user_integral(self, user_id):
        """
        获取用户积分
        :param user_id: 用户唯一id
        :return: 用户当前积分
        """
        return AssetBaseModel(self).get_user_integral(user_id)

    def update_user_integral(self, user_id, asset_value,
                             source_type, source_object_id, source_object_name, log_title,
                             module_id=0, only_id="",
                             info_json=None):
        """
        :description: 变更用户积分
        :param user_id：用户唯一id
        :param asset_value：修改资产值
        :param source_type：来源类型（1-购买2-任务3-手动配置4-抽奖5-回购）
        :param source_object_id：来源对象标识(比如来源类型是任务则对应任务类型)
        :param source_object_name：来源对象名称(比如来源类型是任务则对应任务名称)
        :param log_title：资产流水标题
        :param module_id：模块标识，没有填0
        :param only_id:唯一标识(用于并发操作时校验避免重复操作)由业务方定义传入
        :param info_json：资产流水详情，用于存放业务方自定义字典
        :return: 返回实体InvokeResultData
        :last_editors: SunYiTan
        """
        return AssetBaseModel(self).update_user_integral(
            user_id, asset_value,
            source_type, source_object_id, source_object_name, log_title, module_id, only_id, info_json)

    def get_user_address_info(self, user_id, address_id):
        """
        获取用户收货地址信息
        :param user_id:
        :param address_id
        :return:
        """
        address_dict = PlatformUserAddressModel().get_dict(where="user_id=%s AND address_id=%s AND is_del=0",
                                                           params=[user_id, int(address_id)])
        if not address_dict:
            return None

        temp_dict = {
            "address_id": str(address_dict["address_id"]),  # 地址唯一id
            "user_nick": address_dict["user_nick"],  # 收货人
            "telephone": address_dict["telephone"],  # 手机号
            "province_name": address_dict["province_name"],  # 省份
            "city_name": address_dict["city_name"],  # 城市
            "district_name": address_dict["district_name"],  # 区县
            "address_info": address_dict["address_info"],  # 详细地址
            "is_default": address_dict["is_default"]  # 是否默认，1是 0否
        }

        return temp_dict

    def has_bought_plez(self, user_id):
        """
        判断用户是否过 扑棱蛾子
        :param user_id:
        :return:
        """
        user_dict = PlatformUserInfoModel().get_dict(where="user_id=%s", params=[user_id])
        if not user_dict:
            return False

        total = PlatformDollInfoModel().get_total(
            where="((telephone=%s AND activate_user_id=0) OR user_id=%s) AND goods_code=%s AND get_type=1",
            params=[user_dict["telephone"], user_id, "PLEZ"])
        return True if total and total > 0 else False

    def get_user_follow_status(self, user_id, other_id):
        """
        获取用户关注状态
        :param user_id:  用户平台ID
        :param other_id: 需要查看的其他用户id
        :return: 1关注过 0未关注
        """
        if not user_id or not other_id:
            return 0

        user_id = int(user_id)
        if user_id <= 0:
            return 0

        user_follow_model = PlatformUserFollowModelEx()
        dependency_key = user_follow_model.get_dependency_key(user_id)
        total = user_follow_model.get_cache_total(dependency_key=dependency_key,
                                                  where=f"user_id=%s AND followed_user_id=%s",
                                                  params=[int(user_id), int(other_id)])

        return 1 if total else 0

    def get_followed_user_ids(self, user_id):
        """
        获取关注的用户平台ID列表
        :param user_id: 用户平台ID
        :return:
        """
        user_id = int(user_id)
        if user_id <= 0:
            return []

        user_follow_model = PlatformUserFollowModelEx()
        dependency_key = user_follow_model.get_dependency_key(user_id)
        dict_list = user_follow_model.get_cache_dict_list(dependency_key=dependency_key,
                                                          where=f"user_id=%s",
                                                          field="followed_user_id",
                                                          params=[int(user_id)])

        return [x["followed_user_id"] for x in dict_list]

    def is_mute(self, user_id):
        """
        判断用户是否被禁言
        :param user_id:
        :return:
        """
        if user_id <= 0:
            return False

        user_dict = PlatformUserInfoModel().get_dict(where="user_id=%s", params=[user_id])
        return user_dict and user_dict["status"] == 1 and user_dict["freeze_end_date"] > TimeHelper.get_now_datetime()

    def post_event(self, user_id):
        """
        发帖事件
        :param user_id: 用户平台ID
        :return:
        """
        user_id = int(user_id)
        if user_id <= 0:
            return

        # 数据统计
        UserStatisticsLogModelEx().add_log(user_id, 0, StatisticsOrmType.ClubPost.value, 1)
        UserStatisticsModelEx().add_value(user_id, UserStatisticsType.PostNum.value, 1)

    def comment_post_event(self, user_id, _post_id, reply_id):
        """
        发表评论事件
        :param user_id: 用户平台ID
        :param post_id: 帖子ID
        :param reply_id: 评论ID
        :return:
        """
        user_id = int(user_id)
        if user_id <= 0:
            return

        # 数据统计
        if reply_id <= 0:
            # 不包括评论的评论
            UserStatisticsLogModelEx().add_log(user_id, 0, StatisticsOrmType.ClubComment.value, 1)
        # 包括评论的评论
        UserStatisticsModelEx().add_value(user_id, UserStatisticsType.CommentNum.value, 1)

    def post_dig_event(self, user_id, _post_id, oper_type):
        """
        帖子点赞事件
        :param user_id: 用户平台ID
        :param post_id: 帖子ID
        :param oper_type: 1点赞0取消点赞
        :return:
        """
        user_id = int(user_id)
        if user_id <= 0:
            return

        # 数据统计
        if oper_type == 1:
            UserStatisticsLogModelEx().add_log(user_id, 0, StatisticsOrmType.ClubDig.value, 1)

    def add_search_log(self, search_keyword):
        """
        搜索数据统计
        :param search_keyword:
        :return:
        """
        SearchStatisticsLogModelEx().add_log(search_keyword, 1)


def login_filter(is_check_bind=True):
    """
    :description: 头部过滤装饰器 仅限handler使用
    :param is_check_bind: 是否开启手机号绑定校验
    :last_editors: SunYiTan
    """

    def wrapper(handler):
        def _wrapper(self, **kwargs):
            try:
                header_token = self.request_header_token()
                user_token = header_token.get("UserToken", "")
                jwt_secret = config.get_value("jwt_secret")

                if not user_token:
                    if is_check_bind:
                        self.logging_link_error(f"--- 头部验证信息为空: {self.request.path} : {self.request.headers}")
                        return self.reponse_json_error("TokenEmpty", "非法请求")
                    else:
                        return handler(self, **kwargs)

                sub_info = JwtUtil.get_sub_info_from_token(user_token, jwt_secret)
                user_token_param = UserTokenParam.dict_2_entity(json.loads(sub_info))
                user_id = user_token_param.user_id
                third_auth_id = user_token_param.third_auth_id

                if is_check_bind is True and user_id <= 0:
                    return self.reponse_json_error("UnboundTelephone", "对不起，请先绑定手机号")

                if user_id > 0:
                    # 多平台同时登录，iOS应用和安卓应用不能同时登录
                    app_channel = user_token_param.app_channel
                    if app_channel == AppChannelType.AndroidApp.value:
                        app_channel = AppChannelType.iOSApp.value

                    key = AppBaseRedisKeyType.UserToken.value + str(user_token_param.user_id) + "_" + str(app_channel)
                    # B端用户
                    if user_token_param.user_type == UserType.Business.value:
                        key = f"{key}_{user_token_param.user_type}"
                else:
                    key = AppBaseRedisKeyType.ThirdToken.value + str(third_auth_id)

                redis_util = RedisUtil()
                old_token = redis_util.get(key)
                if not old_token:
                    return self.reponse_json_error("ExpiredSignatureError", "登录已过期，请重新进入小程序")

                if old_token != user_token:
                    return self.reponse_json_error("LoginOther", "对不起，账号在其他地方登录，请重新登录哦~")

                # 延迟时间
                jwt_expire = config.get_value("jwt_expire")
                redis_util.expire(key, jwt_expire * 24 * 60 * 60)

                # 计算停留时间
                if user_id > 0:
                    UserStatisticsLogModelEx().record_remain_time(user_id)

            except ExpiredSignatureError as ex:
                self.logging_link_error(str(ex) + "【登录超时】")
                return self.reponse_json_error("ExpiredSignatureError", "登录已过期，请重新进入小程序")

            except DecodeError as ex:
                self.logging_link_error(str(ex) + "【jwt解码失败】")
                return self.reponse_json_error("DecodeError", "非法请求")

            except Exception as ex:
                self.logging_link_error(traceback.format_exc())
                return self.reponse_json_error("Error", "服务端错误")

            return handler(self, **kwargs)

        return _wrapper

    return wrapper


def add_user_lock(lock_key_head):
    """
    玩家数据加锁，装饰器 仅限handler使用
    :param lock_key_head:
    :return:
    """

    def wrapper(handler):
        def _wrapper(self, **kwargs):

            user_token_param = self.get_user_token_param()
            user_id = user_token_param.user_id

            if user_id <= 0:
                return handler(self, **kwargs)

            lock_key = f"{lock_key_head}:{user_id}"
            redis_util = RedisUtil()
            lock_value = redis_util.acquire_lock_with_timeout(lock_key)
            if lock_value:
                try:

                    ret = handler(self, **kwargs)

                except Exception as e:
                    self.logging_link_error(traceback.format_exc())
                    return self.reponse_json_error("SystemError", "对不起，系统发生错误")

                finally:
                    redis_util.release_lock(lock_key, lock_value)
            else:
                return self.reponse_json_error("LockTimeout", "服务器忙，请稍后再试")

            return ret

        return _wrapper

    return wrapper


def async_func(f):
    """
    异步执行
    :param f:
    :return:
    """

    def wrapper(*args, **kwargs):
        thr = Thread(target=f, args=args, kwargs=kwargs)
        thr.start()

    return wrapper



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/6/18 12:33
:LastEditTime: 2021/6/18 12:33
:LastEditors: SunYiTan
:Description: 
"""


class UserTokenParam:
    """
    user_token参数
    """

    def __init__(self):
        self.user_id = 0  # 平台用户ID
        self.third_auth_id = 0  # 第三方验证唯一id
        self.app_channel = 0  # 登录APP渠道标识，0：NoSdk 1：QQ小程序 2：微信小程序，3：iOS应用，4：安卓应用
        self.user_type = 0  # 用户类型，0：C端用户，1：B端用户
        self.version = 0  # 版本号

    @classmethod
    def dict_2_entity(cls, dict_info):
        obj = cls()
        for (k, v) in dict_info.items():
            if getattr(obj, k, None) is not None:
                setattr(obj, k, v)
        return obj


class UserBaseInfo:
    """
    用户基本信息
    """

    def __init__(self):
        self.user_id = 0  # 用户唯一id
        self.user_nick = ""  # 用户昵称
        self.avatar = ""  # 用户头像
        self.channel = 0  # 登录APP渠道标识，0：NoSdk 1：QQ小程序 2：微信小程序，3：iOS应用，4：安卓应用
        self.app_id = ""  # 第三方app_id
        self.open_id = ""  # open_id



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2020/7/22 13:49
:LastEditTime: 2020/7/22 13:49
:LastEditors: SunYiTan
:Description: jwt认证工具类
"""
import jwt
import time


class JwtUtil:

    @staticmethod
    def create_token(sub_info: str, secret: str, expire: int):
        """
        生成token
        :param user_info:
        :param secret:
        :param expire: 过期时间，天
        :return:
        """
        if expire > 0:
            payload = {
                "iat": int(time.time()),
                "exp": int(time.time()) + 86400 * expire,
                "sub": sub_info
            }
        else:
            payload = {
                "iat": int(time.time()),
                "sub": sub_info
            }

        return jwt.encode(payload, secret, algorithm='HS256').decode()

    @staticmethod
    def get_sub_info_from_token(token, secret: str):
        """
        获取玩家Id
        :param token:
        :param secret:
        :return:
        """
        payload = jwt.decode(token, secret, algorithms='HS256')
        if payload:
            return payload.get("sub")
        else:
            return None



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/4/30 09:23
:LastEditTime: 2021/4/30 09:23
:LastEditors: SunYiTan
:Description: ID生成器，雪花算法
"""
import time
import threading


class InvalidSystemClock(Exception):
    """
    时钟回拨异常
    """
    pass


class IdWorker(object):
    """
    用于生成IDs
    """
    _lock = threading.Condition()

    # 64位ID的划分
    __WORKER_ID_BITS = 5
    __DATACENTER_ID_BITS = 5
    __SEQUENCE_BITS = 12

    # 最大取值计算
    __MAX_WORKER_ID = -1 ^ (-1 << __WORKER_ID_BITS)  # 2**5-1 0b11111
    __MAX_DATACENTER_ID = -1 ^ (-1 << __DATACENTER_ID_BITS)

    # 移位偏移计算
    __WORKER_ID_SHIFT = __SEQUENCE_BITS
    __DATACENTER_ID_SHIFT = __SEQUENCE_BITS + __WORKER_ID_BITS
    __TIMESTAMP_LEFT_SHIFT = __SEQUENCE_BITS + __WORKER_ID_BITS + __DATACENTER_ID_BITS

    # 序号循环掩码
    __SEQUENCE_MASK = -1 ^ (-1 << __SEQUENCE_BITS)

    # Twitter元年时间戳
    __TWEPOCH = 1288834974657

    __worker_id = 0
    __datacenter_id = 0
    __sequence = 0
    __last_timestamp = 0

    @classmethod
    def init(cls, datacenter_id, worker_id, sequence=0):
        """
        初始化
        :param datacenter_id: 数据中心（机器区域）ID
        :param worker_id: 机器ID
        :param sequence: 其实序号
        """
        # sanity check
        if worker_id > cls.__MAX_WORKER_ID or worker_id < 0:
            raise ValueError('worker_id值越界')

        if datacenter_id > cls.__MAX_DATACENTER_ID or datacenter_id < 0:
            raise ValueError('datacenter_id值越界')

        cls.__worker_id = worker_id
        cls.__datacenter_id = datacenter_id
        cls.__sequence = sequence

        cls.__last_timestamp = -1  # 上次计算的时间戳

    @classmethod
    def get_id(cls):
        """
        获取新ID
        :return:
        """
        cls._lock.acquire()
        try:
            timestamp = cls._gen_timestamp()

            # 时钟回拨
            if timestamp < cls.__last_timestamp:
                error = 'clock is moving backwards. Rejecting requests until {}'.format(cls.__last_timestamp)
                raise InvalidSystemClock(error)

            if timestamp == cls.__last_timestamp:
                cls.__sequence = (cls.__sequence + 1) & cls.__SEQUENCE_MASK
                if cls.__sequence == 0:
                    timestamp = cls._til_next_millis(cls.__last_timestamp)
            else:
                cls.__sequence = 0

            cls.__last_timestamp = timestamp

            new_id = ((timestamp - cls.__TWEPOCH) << cls.__TIMESTAMP_LEFT_SHIFT) | (
                    cls.__datacenter_id << cls.__DATACENTER_ID_SHIFT) | \
                     (cls.__worker_id << cls.__WORKER_ID_SHIFT) | cls.__sequence
            return new_id

        except Exception as e:
            raise e
        finally:
            cls._lock.release()

    @classmethod
    def _gen_timestamp(cls):
        """
        生成整数时间戳
        :return:int timestamp
        """
        return int(time.time() * 1000)

    @classmethod
    def _til_next_millis(cls, last_timestamp):
        """
        等到下一毫秒
        """
        timestamp = cls._gen_timestamp()
        while timestamp <= last_timestamp:
            timestamp = cls._gen_timestamp()
        return timestamp




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PlatformUserNoticeModel(BaseModel):
    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformUserNoticeModel, self).__init__(PlatformUserNotice, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PlatformUserNotice:

    def __init__(self):
        super(PlatformUserNotice, self).__init__()
        self.id = 0  # 自增id
        self.notice_id = 0  # 通知唯一id
        self.user_id = 0  # 玩家唯一id
        self.type = 0  # 类型，1系统通知，2游戏通知
        self.notice_type = 0  # 通知类型，101下单通知 102报价通知 103进度更新
        self.description = ""  # 描述
        self.params = ""  # 自定义参数，订单id
        self.param_key = ""  # 参数key值，偷菜用
        self.param_value = ""  # 参数value值，偷菜用
        self.is_show = 0  # 是否展示过，1是 0否
        self.create_date = "1900-01-01 00:00:00"  # 创建时间，注册时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'notice_id', 'user_id', 'type', 'notice_type', 'description', 'params', 'param_key', 'param_value', 'is_show', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "platform_user_notice_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class EzgameUserActionLogModel(BaseModel):
    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(EzgameUserActionLogModel, self).__init__(EzgameUserActionLog, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class EzgameUserActionLog:

    def __init__(self):
        super(EzgameUserActionLog, self).__init__()
        self.id = 0  # 自增id
        self.user_id = 0  # 玩家id
        self.action_id = 0  # 操作id
        self.doll_id = 0  # 玩家id
        self.parama = ""  # parama
        self.paramb = ""  # paramb
        self.paramc = ""  # paramc
        self.paramd = ""  # paramd
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'user_id', 'action_id', 'doll_id', 'parama', 'paramb', 'paramc', 'paramd', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "ezgame_user_action_log_tb"
    


# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/9/3 16:15
:LastEditTime: 2021/9/3 16:15
:LastEditors: SunYiTan
:Description: 百度内容审核
"""
import logging

from aip import AipContentCensor


class BaiduAipCensor:
    """
    百度内容审核：https://cloud.baidu.com/doc/ANTIPORN/s/gk3h6xfxl
    """

    def __init__(self, app_id, api_key, secret_key):
        self.app_id = app_id
        self.api_key = api_key
        self.secret_key = secret_key

    def image_censor(self, url):
        """
        内容审核平台-图像, 图片参数为远程url图片
        :param url:
        :return:
            {'conclusion': '不合规', 'log_id': 16306575473448430, 'data': [{'msg': '存在百度官方违禁图不合规', 'conclusion': '不合规', 'subType': 0, 'conclusionType': 2, 'type': 0}], 'conclusionType': 2}
            {'conclusion': '合规', 'log_id': 16306576034770551, 'isHitMd5': False, 'conclusionType': 1}
        """
        client = AipContentCensor(self.app_id, self.api_key, self.secret_key)
        result = client.imageCensorUserDefined(url)
        # print(result)
        if result.__contains__("conclusionType"):
            if result["conclusionType"] == 1:
                # 合规
                return True, ""
            elif result["conclusionType"] == 2:
                # 不合规
                logging.getLogger("log_error").error(f"违禁图片，url：{url}，result：{result}")
                for data_dict in result["data"]:
                    return False, data_dict["msg"]
                return False, "图片存在违禁内容"
            elif result["conclusionType"] == 3:
                # 疑似
                return True, ""
            else:
                # 4 审核失败
                logging.getLogger("log_error").error(f"图片审核失败，url：{url}，result：{result}")
                return True, ""
        else:
            # 失败
            logging.getLogger("log_error").error(f"图片审核失败，url：{url}，result：{result}")
            return True, ""

    def text_censor(self, text: str):
        """
        内容审核平台-文本
        :param text:
        :return:
            {'conclusion': '不合规', 'log_id': 16318607791718580, 'data': [{'msg': '存在暴恐违禁不合规', 'conclusion': '不合规', 'hits': [{'wordHitPositions': [], 'probability': 0.9854951, 'datasetName': '百度默认文本反作弊库', 'words': [], 'modelHitPositions': [[0, 2, 0.9855]]}], 'subType': 1, 'conclusionType': 2, 'type': 12}, {'msg': '存在政治敏感不合规', 'conclusion': '不合规', 'hits': [{'wordHitPositions': [{'positions': [[0, 2]], 'label': '300101', 'keyword': '江泽民'}], 'probability': 1.0, 'datasetName': '百度默认文本反作弊库', 'words': ['江泽民'], 'modelHitPositions': [[0, 2, 0.9999]]}], 'subType': 3, 'conclusionType': 2, 'type': 12}], 'isHitMd5': False, 'conclusionType': 2}
            {'conclusion': '合规', 'log_id': 16318609705518401, 'isHitMd5': False, 'conclusionType': 1}
        """
        if not text:
            return True, ""

        client = AipContentCensor(self.app_id, self.api_key, self.secret_key)
        result = client.textCensorUserDefined(text)
        # print(result)
        if result.__contains__("conclusionType"):
            if result["conclusionType"] == 1:
                # 合规
                return True, ""
            elif result["conclusionType"] == 2:
                # 不合规
                logging.getLogger("log_error").error(f"违禁文本，text：{text}，result：{result}")
                for data_dict in result["data"]:
                    return False, data_dict["msg"]
                return False, "存在违禁词不合规"
            elif result["conclusionType"] == 3:
                # 疑似
                return True, ""
            else:
                # 4 审核失败
                logging.getLogger("log_error").error(f"文本审核失败，text：{text}，result：{result}")
                return True, ""
        else:
            # 失败
            logging.getLogger("log_error").error(f"文本审核失败，text：{text}，result：{result}")
            return True, ""

    def video_censor(self, video_name, video_url):
        """
        内容审核平台-视频
        :param text:
        :return:
            {"log_id": 15832318739570011, "conclusionType": 2, "conclusion": "不合规", "isHitMd5": false, "msg": "未命中视频黑库", "frames": [{"conclusionType": 2, "conclusion": "不合规", "frameTimeStamp": 0, "frameUrl": "http://bj.bcebos.com/v1/aip-web/2877d59d-414c-4b4f-9b99-9a125b6b2055?authorization=bce-auth-v1%2Ff86a2044998643b5abc89b59158bad6d%2F2020-03-03T10%3A37%3A56Z%2F-1%2F%2F8801a8dc24914caf2ea3d1c360d24002ccbbffb99c3f74d35a1257d07ea15529", "frameThumbnailUrl": "http://bj.bcebos.com/v1/aip-web/84e15149-2f91-4033-bff5-b7c6078107ed?authorization=bce-auth-v1%2Ff86a2044998643b5abc89b59158bad6d%2F2020-03-03T10%3A37%3A56Z%2F-1%2F%2Fa90ef9833579b3503863aea51a47e40ab2cd269a9354d8b0f4730c44803170f5", "data": [{"conclusionType": 2, "conclusion": "不合规", "type": 5, "subType": 1, "msg": "存在公众人物不合规", "stars": [{"probability": 0.96015228271484, "name": "圆圆"}]}]}], "conclusionTypeGroupInfos": [{"msg": "存在watermark不合规", "typeInfo": {"type": "广告检测"}, "subTypeInfoList": [{"subType": "watermark", "timestamp": 0}]}]}
            {'conclusion': '合规', 'log_id': 16318609705518401, 'isHitMd5': False, 'conclusionType': 1}
        """
        ext_id = video_url  # 视频在用户平台的唯一ID，方便人工审核结束时数据推送，用户利用此ID唯一锁定一条平台资源，若无可填写视频Url

        client = AipContentCensor(self.app_id, self.api_key, self.secret_key)
        result = client.videoCensorUserDefined(video_name, video_url, ext_id)
        # print(result)

        frame_url = ""
        if result.__contains__("frames"):
            for frame_dict in result["frames"]:
                frame_url = frame_dict["frameUrl"]
                break

        if result.__contains__("conclusionType"):
            if result["conclusionType"] == 1:
                # 合规
                return True, "", frame_url
            elif result["conclusionType"] == 2:
                # 不合规
                logging.getLogger("log_error").error(f"违禁视频，url：{video_url}，result：{result}")
                for frame_dict in result["frames"]:
                    if frame_dict["conclusionType"] == 2:
                        for data_dict in frame_dict["data"]:
                            if data_dict["conclusionType"] == 2:
                                return False, data_dict["msg"], frame_url
                return False, "视频存在违禁内容", frame_url
            elif result["conclusionType"] == 3:
                # 疑似
                return True, "", frame_url
            else:
                # 4 审核失败
                logging.getLogger("log_error").error(f"视频审核失败，url：{video_url}，result：{result}")
                return False, "视频审核失败", frame_url
        else:
            # 失败
            logging.getLogger("log_error").error(f"视频审核失败，url：{video_url}，result：{result}")
            return True, "视频审核失败，请稍后重试哦", frame_url




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PlatformUserAddressModel(BaseModel):
    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformUserAddressModel, self).__init__(PlatformUserAddress, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PlatformUserAddress:

    def __init__(self):
        super(PlatformUserAddress, self).__init__()
        self.id = 0  # 自增id
        self.address_id = 0  # 地址唯一id
        self.user_id = 0  # 玩家唯一id
        self.user_nick = ""  # 收货人
        self.telephone = ""  # 手机号
        self.province_name = ""  # 省份
        self.city_name = ""  # 城市
        self.district_name = ""  # 区县
        self.address_info = ""  # 详细地址
        self.is_default = 0  # 是否默认，1是 0否
        self.is_del = 0  # 是否删除，1是 0否
        self.create_date = "1900-01-01 00:00:00"  # 创建时间，注册时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'address_id', 'user_id', 'user_nick', 'telephone', 'province_name', 'city_name', 'district_name', 'address_info', 'is_default', 'is_del', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "platform_user_address_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-04-22 14:32:40
:LastEditTime: 2020-07-22 09:59:51
:LastEditors: HuangJingCan
:Description: 常用帮助类
"""
import datetime
import json
import random
import re

from seven_framework import CryptoHelper, config, TimeHelper, HTTPHelper
from seven_framework.base_model import BaseModel
from seven_framework.redis import RedisHelper

from seven_cmstar_platform.models.seven_model import PageInfo

from seven_cmstar_platform.utils.json_util import JsonUtil
from seven_cmstar_platform.utils.redis_util import RedisUtil


class SevenHelper:

    @staticmethod
    def get_condition_by_id_list(primary_key, id_list=None):
        """
        :description: 根据id_list返回查询条件
        :param primary_key：主键
        :param id_list：id：列表
        :return: 查询条件字符串
        :last_editors: HuangJingCan
        """
        if not id_list:
            return ""
        id_list_str = str(id_list).strip('[').strip(']')
        return f"{primary_key} IN({id_list_str})"

    @classmethod
    def get_dict_page_info_list(cls, page_index, page_size, p_dict, total=0):
        """
        :description: 获取分页信息
        :param page_index：页索引
        :param page_size：页大小
        :param p_dict：字典列表
        :return:
        :last_editors: HuangJingCan
        """
        page_info = PageInfo()
        page_info.PageIndex = page_index
        page_info.PageSize = page_size
        page_info.RecordCount = total if total > 0 else len(p_dict)
        page_info.Data = p_dict
        page_info = page_info.get_entity_by_page_info(page_info)
        return page_info.__dict__

    @classmethod
    def to_file_size(cls, size):
        """
        :description: 文件大小格式化
        :param size：文件大小
        :return:
        :last_editors: HuangJingCan
        """
        if size < 1000:
            return '%i' % size + 'size'
        elif 1024 <= size < 1048576:
            return '%.2f' % float(size / 1024) + 'KB'
        elif 1048576 <= size < 1073741824:
            return '%.2f' % float(size / 1048576) + 'MB'
        elif 1073741824 <= size < 1000000000000:
            return '%.2f' % float(size / 1073741824) + 'GB'
        elif 1000000000000 <= size:
            return '%.2f' % float(size / 1000000000000) + 'TB'

    @classmethod
    def get_random(cls, num, many):
        """
        :description: 获取随机数
        :param num：位数
        :param many：个数
        :return:
        :last_editors: CaiYouBin
        """
        result = ""
        for x in range(many):
            s = ""
            for i in range(num):
                # n=1 生成数字  n=2 生成字母
                n = random.randint(1, 2)
                if n == 1:
                    numb = random.randint(0, 9)
                    s += str(numb)
                else:
                    nn = random.randint(1, 2)
                    cc = random.randint(1, 26)
                    if nn == 1:
                        numb = chr(64 + cc)
                        s += numb
                    else:
                        numb = chr(96 + cc)
                        s += numb
            result += s
        return result

    @classmethod
    def get_cache_entity(cls, model: BaseModel, dependency_key,
                         where='', group_by='', order_by='', params=None,
                         expire_sec=10 * 60):
        redis_cli = RedisUtil()
        cache_key = f"{where}_{group_by}_{order_by}_{params}_{model.model_obj.get_field_list()}"
        cache_key = CryptoHelper.md5_encrypt(cache_key.lower())
        cache_key = f"entity_{cache_key}"
        s = redis_cli.hget(dependency_key, cache_key)
        if s:
            return model._BaseModel__row_entity(json.loads(s))

        dict_info = model.get_entity(where, group_by, order_by, params)
        if not dict_info:
            return None

        redis_cli.hset(dependency_key, cache_key, JsonUtil.dumps(dict_info))
        redis_cli.expire(dependency_key, expire_sec)
        return dict_info

    @classmethod
    def get_cache_entity_by_id(cls, model: BaseModel, dependency_key,
                               primary_key_id,
                               expire_sec=10 * 60):
        redis_cli = RedisUtil()
        cache_key = f"{primary_key_id}_{model.model_obj.get_field_list()}"
        cache_key = CryptoHelper.md5_encrypt(cache_key.lower())
        cache_key = f"entity_by_id_{cache_key}"
        s = redis_cli.hget(dependency_key, cache_key)
        if s:
            return model._BaseModel__row_entity(json.loads(s))

        dict_info = model.get_entity_by_id(primary_key_id)
        if not dict_info:
            return None

        redis_cli.hset(dependency_key, cache_key, JsonUtil.dumps(dict_info))
        redis_cli.expire(dependency_key, expire_sec)
        return dict_info

    @classmethod
    def get_cache_list(cls, model: BaseModel, dependency_key,
                       where='', group_by='', order_by='', limit='', params=None,
                       expire_sec=10 * 60):
        redis_cli = RedisUtil()
        cache_key = f"{where}_{group_by}_{order_by}_{limit}_{params}_{model.model_obj.get_field_list()}"
        cache_key = CryptoHelper.md5_encrypt(cache_key.lower())
        cache_key = f"list_{cache_key}"
        s = redis_cli.hget(dependency_key, cache_key)
        if s:
            return model._BaseModel__row_entity_list(json.loads(s))

        dict_list = model.get_list(where, group_by, order_by, limit, params)

        redis_cli.hset(dependency_key, cache_key, JsonUtil.dumps(dict_list))
        redis_cli.expire(dependency_key, expire_sec)
        return dict_list

    @classmethod
    def get_cache_page_list(cls, model: BaseModel, dependency_key,
                            field, page_index, page_size, where='', group_by='', order_by='', params=None,
                            expire_sec=10 * 60):
        redis_cli = RedisUtil()
        cache_key = f"{field}_{page_index}_{page_size}_{where}_{group_by}_{order_by}_{params}_{model.model_obj.get_field_list()}"
        cache_key = CryptoHelper.md5_encrypt(cache_key.lower())
        cache_key = f"page_list_{cache_key}"
        s = redis_cli.hget(dependency_key, cache_key)
        if s:
            value = json.loads(s)
            return model._BaseModel__row_entity_list(value["dict_list"]), value["total"]

        dict_list, total = model.get_page_list(field, page_index, page_size, where, group_by, order_by, params)
        value = {"dict_list": dict_list, "total": total}

        redis_cli.hset(dependency_key, cache_key, JsonUtil.dumps(value))
        redis_cli.expire(dependency_key, expire_sec)
        return dict_list, total

    @classmethod
    def get_cache_dict(cls, model: BaseModel, dependency_key,
                       where='', group_by='', order_by='', limit='', field="*", params=None,
                       expire_sec=10 * 60):
        redis_cli = RedisUtil()
        cache_key = f"{where}_{group_by}_{order_by}_{limit}_{field}_{params}_{model.model_obj.get_field_list()}"
        cache_key = CryptoHelper.md5_encrypt(cache_key.lower())
        cache_key = f"dict_{cache_key}"
        s = redis_cli.hget(dependency_key, cache_key)
        if s:
            return json.loads(s)

        dict_info = model.get_dict(where, group_by, order_by, limit, field, params)
        if not dict_info:
            return None

        redis_cli.hset(dependency_key, cache_key, JsonUtil.dumps(dict_info))
        redis_cli.expire(dependency_key, expire_sec)
        return dict_info

    @classmethod
    def get_cache_dict_by_id(cls, model: BaseModel, dependency_key,
                             primary_key_id,
                             expire_sec=10 * 60):
        redis_cli = RedisUtil()
        s = redis_cli.hget(dependency_key, primary_key_id)
        if s:
            return json.loads(s)

        dict_info = model.get_dict_by_id(primary_key_id)
        if not dict_info:
            return None

        redis_cli.hset(dependency_key, primary_key_id, JsonUtil.dumps(dict_info))
        redis_cli.expire(dependency_key, expire_sec)
        return dict_info

    @classmethod
    def get_cache_dict_by_id_new(cls, model: BaseModel, dependency_key,
                                 primary_key_id, field="*",
                                 expire_sec=10 * 60):
        redis_cli = RedisUtil()
        cache_key = f"{primary_key_id}_{field}_{model.model_obj.get_field_list()}"
        cache_key = CryptoHelper.md5_encrypt(cache_key.lower())
        cache_key = f"dict_by_id_{cache_key}"
        s = redis_cli.hget(dependency_key, cache_key)
        if s:
            return json.loads(s)

        dict_info = model.get_dict_by_id(primary_key_id, field)
        if not dict_info:
            return None

        redis_cli.hset(dependency_key, cache_key, JsonUtil.dumps(dict_info))
        redis_cli.expire(dependency_key, expire_sec)
        return dict_info

    @classmethod
    def get_cache_dict_list(cls, model: BaseModel, dependency_key,
                            where='', group_by='', order_by='', limit='', field="*", params=None,
                            expire_sec=10 * 60):
        redis_cli = RedisUtil()
        cache_key = f"{where}_{group_by}_{order_by}_{limit}_{field}_{params}_{model.model_obj.get_field_list()}"
        cache_key = CryptoHelper.md5_encrypt(cache_key.lower())
        cache_key = f"dict_list_{cache_key}"
        s = redis_cli.hget(dependency_key, cache_key)
        if s:
            return json.loads(s)

        dict_list = model.get_dict_list(where, group_by, order_by, limit, field, params)

        redis_cli.hset(dependency_key, cache_key, JsonUtil.dumps(dict_list))
        redis_cli.expire(dependency_key, expire_sec)
        return dict_list

    @classmethod
    def get_cache_dict_page_list(cls, model: BaseModel, dependency_key,
                                 field,
                                 page_index,
                                 page_size,
                                 where='',
                                 group_by='',
                                 order_by='',
                                 params=None,
                                 expire_sec=10 * 60):
        redis_cli = RedisUtil()
        cache_key = f"{field}_{page_index}_{page_size}_{where}_{group_by}_{order_by}_{params}_{model.model_obj.get_field_list()}"
        cache_key = CryptoHelper.md5_encrypt(cache_key.lower())
        cache_key = f"dict_page_list_{cache_key}"
        s = redis_cli.hget(dependency_key, cache_key)
        if s:
            value = json.loads(s)
            return value["dict_list"], value["total"]

        dict_list, total = model.get_dict_page_list(field, page_index, page_size, where, group_by, order_by, params)
        value = {"dict_list": dict_list, "total": total}

        redis_cli.hset(dependency_key, cache_key, JsonUtil.dumps(value))
        redis_cli.expire(dependency_key, expire_sec)
        return dict_list, total

    @classmethod
    def get_cache_total(cls, model: BaseModel, dependency_key,
                        where='', group_by='', field=None, params=None,
                        expire_sec=10 * 60):
        redis_cli = RedisUtil()
        cache_key = f"{where}_{group_by}_{field}_{params}_{model.model_obj.get_field_list()}"
        cache_key = CryptoHelper.md5_encrypt(cache_key.lower())
        cache_key = f"total_{cache_key}"
        s = redis_cli.hget(dependency_key, cache_key)
        if s:
            return int(json.loads(s))

        total = model.get_total(where, group_by, field, params)

        redis_cli.hset(dependency_key, cache_key, total)
        redis_cli.expire(dependency_key, expire_sec)
        return total

    @classmethod
    def delete_cache(cls, dependency_key):
        redis_cli = RedisUtil()
        redis_cli.delete(dependency_key)

    @classmethod
    def delete_cache_by_id(cls, dependency_key, primary_key_id):
        redis_cli = RedisUtil()
        redis_cli.hdel(dependency_key, primary_key_id)

    @classmethod
    def redis_init(self, db=None):
        """
        :description: redis初始化
        :return: redis_cli
        :last_editors: HuangJingCan
        """
        host = config.get_value("redis")["host"]
        port = config.get_value("redis")["port"]
        if not db:
            db = config.get_value("redis")["db"]
        password = config.get_value("redis")["password"]
        redis_cli = RedisHelper.redis_init(host, port, db, password)
        return redis_cli

    @classmethod
    def get_now_int(self, hours=0, fmt='%Y%m%d%H%M%S'):
        """
        :description: 获取整形的时间 格式为yyyyMMddHHmmss，如2009年12月27日9点10分10秒表示为20091227091010
        :param hours: 需要增加的小时数
        :param fmt: 时间格式
        :return:
        :last_editors: HuangJianYi
        """
        now_date = (datetime.datetime.now() + datetime.timedelta(hours=hours))
        return int(now_date.strftime(fmt))

    @classmethod
    def get_now_day_int(self, hours=0):
        """
        :description: 获取整形的天20200506
        :param hours: 需要增加的小时数
        :return: int（20200506）
        :last_editors: HuangJianYi
        """
        return self.get_now_int(fmt='%Y%m%d')

    @classmethod
    def get_now_datetime(self):
        """
        :description: 获取当前时间
        :return: str
        :last_editors: HuangJianYi
        """
        add_hours = config.get_value("add_hours", 0)
        return TimeHelper.add_hours_by_format_time(hour=add_hours)

    @classmethod
    def datetime_to_int(cls, dt, fmt='%Y%m%d%H%M%S'):
        return int(dt.strftime(fmt))

    @classmethod
    def base64_encode(cls, source, encoding="utf-8"):
        """
        :Description: base64加密
        :param source: 需加密的字符串
        :return: 加密后的字符串
        :last_editors: HuangJianYi
        """
        if not source.strip():
            return ""
        import base64
        encode_string = str(base64.b64encode(source.encode(encoding=encoding)), 'utf-8')
        return encode_string

    @classmethod
    def base64_decode(cls, source):
        """
        :Description: base64解密
        :param source: 需加密的字符串
        :return: 解密后的字符串
        :last_editors: HuangJianYi
        """
        if not source.strip():
            return ""
        import base64
        decode_string = str(base64.b64decode(source), 'utf-8')
        return decode_string

    @classmethod
    def emoji_base64_to_emoji(cls, text_string):
        """
        :description: 把加密后的表情还原
        :param text_string: 加密后的字符串
        :return: 解密后的表情字符串
        :last_editors: HuangJianYi
        """
        if not text_string:
            return ""

        results = re.findall('\[em_(.*?)\]', text_string)
        if results:
            for item in results:
                text_string = text_string.replace("[em_{0}]".format(item), cls.base64_decode(item))
        return text_string

    @classmethod
    def emoji_to_emoji_base64(cls, text_string):
        """
        :description: emoji表情转为[em_xxx]形式存于数据库,打包每一个emoji
        :description: 性能遇到问题时重新设计转换程序
        :param text_string: 未加密的字符串
        :return: 解密后的表情字符串
        """
        if not text_string:
            return ""

        try:
            co = re.compile(u'[\U00010000-\U0010ffff]')
        except re.error:
            co = re.compile(u'[\uD800-\uDBFF][\uDC00-\uDFFF]')
        results = co.findall(text_string)
        if results:
            for item in results:
                emoji_base64 = cls.base64_encode(item)
                text_string = text_string.replace(item, "[em_" + emoji_base64 + "]")
        return text_string

    @classmethod
    def long2short(cls, long_url):
        """
        长链接转短链接，公司接口，灿哥维护，地址中需要存在 gao7.com
        :param access_token:
        :return:
        {'ResultCode': '0', 'ResultMessage': '调用成功', 'Data': [{'ShortUrl': 'http://t.yinews.cn/QniAFv', 'IsNumberUrl': False}]}
        """
        url = f"http://t.yinews.cn/Create"
        params = {
            "url": long_url
        }

        response = HTTPHelper.get(url, params, headers={'Content-Type': 'application/json'})
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"ResultCode": '-1', "ResultMessage": "接口请求失败"}




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PlatformUserFollowModel(BaseModel):
    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformUserFollowModel, self).__init__(PlatformUserFollow, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PlatformUserFollow:

    def __init__(self):
        super(PlatformUserFollow, self).__init__()
        self.id = 0  # 自增id
        self.user_id = 0  # 用户id
        self.followed_user_id = 0  # 关注的用户id
        self.user_type = 0  # 用户类型 1真实用户2随机马甲用户3官方马甲用户4普通马甲用户5特权用户
        self.followed_user_type = 0  # 关注的用户类型 1真实用户2随机马甲用户3官方马甲用户4普通马甲用户5特权用户
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'user_id', 'followed_user_id', 'user_type', 'followed_user_type', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "platform_user_follow_tb"
    


# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/10/12 18:07
:LastEditTime: 2021/10/12 18:07
:LastEditors: SunYiTan
:Description: 
"""
from seven_framework.base_model import *

from seven_cmstar_platform.models.cache_model import CacheModel
from seven_cmstar_platform.models.db_models.platform.platform_user_fans_model import PlatformUserFans
from seven_cmstar_platform.models.enum import RedisKeyType


class PlatformUserFansModelEx(CacheModel):
    __CACHE_KEY = RedisKeyType.PtUserFansCache.value

    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformUserFansModelEx, self).__init__(PlatformUserFans, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    @classmethod
    def get_dependency_key(self, user_id):
        return f"{self.__CACHE_KEY}:{user_id}"



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/8/11 09:51
:LastEditTime: 2021/8/11 09:51
:LastEditors: SunYiTan
:Description: 微信小游戏帮助类
"""
import base64
import json
import logging
import traceback

from Crypto.Cipher import AES
from seven_framework import HTTPHelper, TimeHelper

from seven_cmstar_platform.models.enum import AppBaseRedisKeyType
from seven_cmstar_platform.utils.json_util import JsonUtil
from seven_cmstar_platform.utils.redis_util import RedisUtil


class WxMiniHelper:

    @classmethod
    def code_to_session(cls, code: str, app_id: str, app_secret: str):
        """
        微信验证
        :param code:
        :param app_id:
        :param app_secret:
        :return:
        {"session_key":"oKR7CraC4X0aR6xxxx","openid":"oHUq14ilDpKbS4NQpxxxx"}

        """
        url = f"https://api.weixin.qq.com/sns/jscode2session?appid={app_id}" \
              f"&secret={app_secret}&js_code={code}&grant_type=authorization_code"

        response = HTTPHelper.get(url)
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errcode": -1, "errmsg": "接口请求失败"}

    @classmethod
    def get_access_token(cls, app_id: str, app_secret: str):
        """
        获取AccessToken
        参考文档：https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/access-token/auth.getAccessToken.html
        :param app_id:
        :param app_secret:
        :return:
        {
            'access_token': '49_XDvBlBxRCMEUmpH_W1BHTSuQf4oxxx',
            'expires_in': 7200
        }
        """
        url = f"https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid={app_id}&secret={app_secret}"

        response = HTTPHelper.get(url)
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errcode": -1, "errmsg": "接口请求失败"}

    @classmethod
    def get_access_token_cache(cls, app_id: str, app_secret: str):
        key = AppBaseRedisKeyType.WxAccessToken.value + app_id
        now = TimeHelper.get_now_timestamp()
        token = ""
        refresh_time = 0
        expires_in = 0

        s = RedisUtil().get(key)
        if s:
            token_info = json.loads(s)
            token = token_info["access_token"]
            refresh_time = token_info["refresh_time"]
            expires_in = token_info["expires_in"]

        if not s or now >= refresh_time + expires_in:
            token = cls.__refresh_access_token(app_id, app_secret)

        return token

    @classmethod
    def __refresh_access_token(cls, app_id: str, app_secret: str):
        lock_key = AppBaseRedisKeyType.WxAccessTokenLock.value + app_id
        redis_util = RedisUtil()
        lock_value = redis_util.acquire_lock_with_timeout(lock_key)
        if lock_value:
            try:
                key = AppBaseRedisKeyType.WxAccessToken.value + app_id
                now = TimeHelper.get_now_timestamp()
                token = ""
                refresh_time = 0
                expires_in = 0

                # 防止重复刷新
                s = RedisUtil().get(key)
                if s:
                    token_info = json.loads(s)
                    token = token_info["access_token"]
                    refresh_time = token_info["refresh_time"]
                    expires_in = token_info["expires_in"]
                if s and now < refresh_time + expires_in and now - refresh_time <= 10:
                    return token

                result = cls.get_access_token(app_id, app_secret)
                if result.__contains__("errcode") and result["errcode"] != 0:
                    logging.getLogger().error(f"get access token fail from weixin: {result}")
                    return ""

                token_info = {
                    "access_token": result["access_token"],
                    "expires_in": result["expires_in"],
                    "refresh_time": now
                }

                RedisUtil().set(key, JsonUtil.dumps(token_info))
                return result["access_token"]

            except Exception as e:
                logging.getLogger().error(traceback.format_exc())

            finally:
                redis_util.release_lock(lock_key, lock_value)
        else:
            return ""

    @classmethod
    def decrypt_data(self, app_id, session_key, encrypted_data, iv):
        """
        :description:解析加密数据
        :param app_id: 微信小程序标识
        :param session_key: session_key调用登录接口获得
        :param encrypted_data：加密数据,微信返回加密参数
        :param iv：微信返回参数
        :return: 解密后的数据，用户信息或者手机号信息
        :last_editors: HuangJianYi
        """
        data = {}
        try:
            wx_data_crypt = WXBizDataCrypt(app_id, session_key)
            data = wx_data_crypt.decrypt(encrypted_data, iv)  # data中是解密的信息
        except Exception as ex:
            logging.getLogger("log_error").error(str(ex) + "【微信decrypted_data】")
        return data

    @classmethod
    def generate_scheme(cls, access_token, path, query, env_version):
        """
        获取小程序 scheme 码，适用于短信、邮件、外部网页、微信内等拉起小程序的业务场景
        参考文档：https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/url-scheme/urlscheme.generate.html
        :param access_token:
        :param path:
        :param query:
        :param env_version: 要打开的小程序版本。正式版为"release"，体验版为"trial"，开发版为"develop"
        {'errcode': 0, 'errmsg': 'ok', 'openlink': 'weixin://dl/business/?t=yRF6MvAltgb'}
        """
        url = f"https://api.weixin.qq.com/wxa/generatescheme?access_token={access_token}"

        data = {
            "jump_wxa":
                {
                    "path": path,
                    "query": query,
                    "env_version": env_version
                },
            "is_expire": True,
            "expire_time": TimeHelper.get_now_timestamp() + 7 * 24 * 60 * 60
        }
        response = HTTPHelper.post(url, data, headers={'Content-Type': 'application/json'})
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errcode": -1, "errmsg": "接口请求失败"}

    @classmethod
    def generate_url_link(cls, access_token, path, query, env_version):
        """
        获取小程序 URL Link，适用于短信、邮件、网页、微信内等拉起小程序的业务场景
        参考文档：https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/url-link/urllink.generate.html
        :param access_token:
        :param path:
        :param query:
        :param env_version: 要打开的小程序版本。正式版为"release"，体验版为"trial"，开发版为"develop"
        {'errcode': 0, 'errmsg': 'ok', 'url_link': 'https://wxaurl.cn/MMdNDf6qiUt'}
        """
        url = f"https://api.weixin.qq.com/wxa/generate_urllink?access_token={access_token}"

        data = {
            "path": path,
            "query": query,
            "env_version": env_version,
            "is_expire": True,
            "expire_time": TimeHelper.get_now_timestamp() + 7 * 24 * 60 * 60
        }

        response = HTTPHelper.post(url, data, headers={'Content-Type': 'application/json'})
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errcode": -1, "errmsg": "接口请求失败"}

    @classmethod
    def mp_subscribe_message_send(cls, access_token, mp_template_id, app_id, page_path, open_id, content):
        """
        发送公众号订阅消息
        参考文档：https://developers.weixin.qq.com/doc/offiaccount/Subscription_Messages/api.html#send%E5%8F%91%E9%80%81%E8%AE%A2%E9%98%85%E9%80%9A%E7%9F%A5
        :param access_token:
        :param mp_template_id:
        :param app_id:
        :param page_path:
        :param open_id:
        :param content:
        :return:
        """
        url = f"https://api.weixin.qq.com/cgi-bin/message/subscribe/bizsend?access_token={access_token}"

        data = {
            "touser": open_id,
            "template_id": mp_template_id,
            "page": "",
            "miniprogram": {
                "appid": app_id,
                "pagepath": page_path
            },
            "data": content
        }

        response = HTTPHelper.post(url, data, headers={'Content-Type': 'application/json'})
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errcode": -1, "errmsg": "接口请求失败"}

    @classmethod
    def uniform_message_send(cls, access_token, mp_appid, mp_template_id, app_id, page_path, open_id, content):
        """
        下发小程序和公众号统一的服务消息
        参考文档：https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/uniform-message/uniformMessage.send.html
        :param access_token:
        :param mp_appid:
        :param mp_template_id:
        :param app_id:
        :param page_path:
        :param open_id:
        :param content:
        :return:
        """
        url = f"https://api.weixin.qq.com/cgi-bin/message/wxopen/template/uniform_send?access_token={access_token}"

        data = {
            "touser": open_id,
            "mp_template_msg": {
                "appid": mp_appid,
                "template_id": mp_template_id,
                "url": "",
                "miniprogram": {
                    "appid": app_id,
                    "pagepath": page_path
                },
                "data": content
            }
        }

        response = HTTPHelper.post(url, data, headers={'Content-Type': 'application/json'})
        if response.status_code == 200:
            return json.loads(response.text)
        else:
            return {"errcode": -1, "errmsg": "接口请求失败"}


class WXBizDataCrypt:
    def __init__(self, appId, sessionKey):
        self.appId = appId
        self.sessionKey = sessionKey

    def decrypt(self, encryptedData, iv):
        # base64 decode
        sessionKey = base64.b64decode(self.sessionKey)
        encryptedData = base64.b64decode(encryptedData)
        iv = base64.b64decode(iv)

        cipher = AES.new(sessionKey, AES.MODE_CBC, iv)

        decrypted = json.loads(self._unpad(cipher.decrypt(encryptedData)))

        if decrypted['watermark']['appid'] != self.appId:
            raise Exception('Invalid Buffer')

        return decrypted

    def _unpad(self, s):
        return s[:-ord(s[len(s) - 1:])]



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/10/27 09:33
:LastEditTime: 2021/10/27 09:33
:LastEditors: SunYiTan
:Description: 
"""
from seven_framework import TimeHelper

from seven_cmstar_platform.models.db_models.platform.platform_user_statistics_model import PlatformUserStatisticsModel, \
    PlatformUserStatistics
from seven_cmstar_platform.models.enum import UserStatisticsType


class UserStatisticsModelEx(PlatformUserStatisticsModel):

    def add_value(self, user_id: int, statistics_type: UserStatisticsType, add_value):
        """
        增加用户统计信息
        :param user_id:
        :param statistics_type:
        :param add_value:
        :return:
        """
        now_date = TimeHelper.get_now_datetime()

        statistics_info = self.get_dict(where="user_id=%s", params=[user_id])

        if statistics_info:
            if statistics_type == UserStatisticsType.DollNum.value:
                update_sql = "doll_num=doll_num+%s"
            elif statistics_type == UserStatisticsType.ClothNum.value:
                update_sql = "cloth_num=cloth_num+%s"
            elif statistics_type == UserStatisticsType.PostNum.value:
                update_sql = "post_num=post_num+%s"
            elif statistics_type == UserStatisticsType.CommentNum.value:
                update_sql = "comment_num=comment_num+%s"
            elif statistics_type == UserStatisticsType.ApplyNum.value:
                update_sql = "apply_num=apply_num+%s"
            elif statistics_type == UserStatisticsType.QuotationNum.value:
                update_sql = "quotation_num=quotation_num+%s"
            elif statistics_type == UserStatisticsType.OrderNum.value:
                update_sql = "order_num=order_num+%s"
            else:
                return
            self.update_table(update_sql=update_sql, where="user_id=%s",
                              params=[add_value, user_id])

        else:
            statistics_info = PlatformUserStatistics()
            statistics_info.user_id = user_id
            statistics_info.create_date = now_date
            statistics_info.modify_date = now_date

            if statistics_type == UserStatisticsType.DollNum.value:
                statistics_info.doll_num = add_value
            elif statistics_type == UserStatisticsType.ClothNum.value:
                statistics_info.cloth_num = add_value
            elif statistics_type == UserStatisticsType.PostNum.value:
                statistics_info.post_num = add_value
            elif statistics_type == UserStatisticsType.CommentNum.value:
                statistics_info.comment_num = add_value
            elif statistics_type == UserStatisticsType.ApplyNum.value:
                statistics_info.apply_num = add_value
            elif statistics_type == UserStatisticsType.QuotationNum.value:
                statistics_info.quotation_num = add_value
            elif statistics_type == UserStatisticsType.OrderNum.value:
                statistics_info.order_num = add_value
            else:
                return

            self.add_entity(statistics_info)



__all__=["platform_user_fans_model","platform_asset_warn_notice_model","platform_asset_log_model","platform_user_third_auth_model","platform_search_statistics_log_model","platform_user_statistics_model","platform_user_statistics_log_model","platform_asset_inventory_model","platform_user_info_model","platform_user_address_model","platform_user_auth_rel_model","platform_user_follow_model","platform_user_notice_model","platform_asset_only_model","platform_base_info_model","platform_dict_info_model","platform_user_asset_model","platform_doll_info_model",]


# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/10/11 09:30
:LastEditTime: 2021/10/11 09:30
:LastEditors: SunYiTan
:Description: 
"""
import datetime

from seven_framework import TimeHelper, config
from seven_framework.base_model import BaseModel

from seven_cmstar_platform.utils.seven import SevenHelper


class CacheModel(BaseModel):

    def __init__(self, model_class, sub_table):
        """
        :Description: 数据缓存业务模型
        :param model_class: 实体对象类
        :param sub_table: 分表标识
        :last_editors: SunYiTan
        """
        super(CacheModel, self).__init__(model_class, sub_table)

    def get_format_time_list(self):
        """
        返回需要转换成日期格式的字段，继承类复写
        :return:
        """
        return ["create_date", "modify_date"]

    def get_cache_entity(self, dependency_key, where='', group_by='', order_by='', params=None, expire_sec=None):
        expire_sec = expire_sec if expire_sec else config.get_value("cache_expire_minute", 60) * 60
        return SevenHelper.get_cache_entity(self, dependency_key,
                                            where, group_by, order_by, params, expire_sec)

    def get_cache_entity_by_id(self, dependency_key, primary_key_id, expire_sec=None):
        expire_sec = expire_sec if expire_sec else config.get_value("cache_expire_minute", 60) * 60
        return SevenHelper.get_cache_entity_by_id(self, dependency_key, primary_key_id, expire_sec)

    def get_cache_list(self, dependency_key, where='', group_by='', order_by='', limit='', params=None,
                       expire_sec=None):
        expire_sec = expire_sec if expire_sec else config.get_value("cache_expire_minute", 60) * 60
        return SevenHelper.get_cache_list(self, dependency_key, where, group_by, order_by, limit, params, expire_sec)

    def get_cache_page_list(self, dependency_key,
                            field, page_index, page_size, where='', group_by='', order_by='', params=None,
                            expire_sec=None):
        expire_sec = expire_sec if expire_sec else config.get_value("cache_expire_minute", 60) * 60
        return SevenHelper.get_cache_page_list(self, dependency_key,
                                               field, page_index, page_size, where, group_by, order_by, params,
                                               expire_sec)

    def get_cache_dict(self, dependency_key, where='', group_by='', order_by='', limit='', field="*", params=None,
                       expire_sec=None):
        expire_sec = expire_sec if expire_sec else config.get_value("cache_expire_minute", 60) * 60
        dict_info = SevenHelper.get_cache_dict(self, dependency_key,
                                               where, group_by, order_by, limit, field, params, expire_sec)
        if dict_info:
            self.__format_time_to_datetime(dict_info)
        return dict_info

    def get_cache_dict_by_id(self, dependency_key, primary_key_id, field="*", expire_sec=None):
        expire_sec = expire_sec if expire_sec else config.get_value("cache_expire_minute", 60) * 60
        dict_info = SevenHelper.get_cache_dict_by_id_new(self, dependency_key, primary_key_id, field, expire_sec)
        if dict_info:
            self.__format_time_to_datetime(dict_info)
        return dict_info

    def get_cache_dict_list(self, dependency_key, where='', group_by='', order_by='', limit='', field="*", params=None,
                            expire_sec=None):
        expire_sec = expire_sec if expire_sec else config.get_value("cache_expire_minute", 60) * 60
        dict_list = SevenHelper.get_cache_dict_list(self, dependency_key,
                                                    where, group_by, order_by, limit, field, params, expire_sec)
        for dict_info in dict_list:
            self.__format_time_to_datetime(dict_info)
        return dict_list

    def get_cache_dict_page_list(self, dependency_key,
                                 field, page_index, page_size, where='', group_by='', order_by='', params=None,
                                 expire_sec=None):
        expire_sec = expire_sec if expire_sec else config.get_value("cache_expire_minute", 60) * 60
        dict_list, total = SevenHelper.get_cache_dict_page_list(
            self, dependency_key,
            field, page_index, page_size, where, group_by, order_by, params, expire_sec)
        for dict_info in dict_list:
            self.__format_time_to_datetime(dict_info)
        return dict_list, total

    def get_cache_total(self, dependency_key, where='', group_by='', field=None, params=None, expire_sec=None):
        expire_sec = expire_sec if expire_sec else config.get_value("cache_expire_minute", 60) * 60
        return SevenHelper.get_cache_total(self, dependency_key, where, group_by, field, params, expire_sec)

    def __format_time_to_datetime(self, dict_info):
        format_time_list = self.get_format_time_list()
        for key in format_time_list:
            if dict_info.__contains__(key) and not isinstance(dict_info[key], datetime.datetime):
                dict_info[key] = TimeHelper.format_time_to_datetime(dict_info[key])

    def delete_cache(self, dependency_key):
        """
        删除缓存
        :return:
        """
        SevenHelper.delete_cache(dependency_key)

    def add_entity_cache(self, model, dependency_key, ignore=False):
        self.delete_cache(dependency_key)
        new_id = super(CacheModel, self).add_entity(model, ignore)
        self.delete_cache(dependency_key)
        return new_id

    def update_entity_cache(self, model, dependency_key, field_list=None, exclude_field_list=None):
        self.delete_cache(dependency_key)
        super(CacheModel, self).update_entity(model, field_list, exclude_field_list)
        self.delete_cache(dependency_key)

    def update_table_cache(self, dependency_key, update_sql, where, params=None):
        self.delete_cache(dependency_key)
        super(CacheModel, self).update_table(update_sql, where, params)
        self.delete_cache(dependency_key)

    def del_entity_cache(self, dependency_key, where, params=None):
        self.delete_cache(dependency_key)
        super(CacheModel, self).del_entity(where, params)
        self.delete_cache(dependency_key)



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/10/29 17:22
:LastEditTime: 2021/10/29 17:22
:LastEditors: SunYiTan
:Description: 娃娃平台帮助类
"""
from seven_cmstar_platform.models.db_models_ex.platform.platform_user_notice_model_ex import PlatformUserNoticeModelEx
from seven_cmstar_platform.models.enum import UserNoticeNumType


class DollAppHelper:

    @staticmethod
    def add_new_notice_num(user_id, notice_num_type: UserNoticeNumType, inc_value):
        """
        增加通知数量，用于小红点显示未读数量
        :param user_id:
        :param notice_num_type:
        :param inc_value:
        :return:
        """
        PlatformUserNoticeModelEx().add_new_notice_num(user_id, notice_num_type, inc_value)

    @staticmethod
    def clear_new_notice_num(user_id, notice_num_type: UserNoticeNumType):
        """
        清空通知数量，点击查看后清空
        :param user_id:
        :param notice_num_type:
        :return:
        """
        PlatformUserNoticeModelEx().clear_new_notice_num(user_id, notice_num_type)



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/10/29 16:35
:LastEditTime: 2021/10/29 16:35
:LastEditors: SunYiTan
:Description: 用户通知模块
"""
from seven_cmstar_platform.models.db_models.platform.platform_user_notice_model import PlatformUserNoticeModel
from seven_cmstar_platform.models.enum import UserNoticeNumType, RedisKeyType
from seven_cmstar_platform.utils.redis_util import RedisUtil


class PlatformUserNoticeModelEx(PlatformUserNoticeModel):

    def add_new_notice_num(self, user_id, notice_num_type: UserNoticeNumType, inc_value):
        """
        增加通知数量，用于小红点显示未读数量
        :param user_id:
        :param notice_num_type:
        :param inc_value:
        :return:
        """
        redis_cli = RedisUtil()
        name = f"{RedisKeyType.PtUserNotifyNum.value}:{user_id}"
        redis_cli.hincrby(name, notice_num_type, inc_value)

    def clear_new_notice_num(self, user_id, notice_num_type: UserNoticeNumType):
        """
        清空通知数量，点击查看后清空
        :param user_id:
        :param notice_num_type:
        :return:
        """
        redis_cli = RedisUtil()
        name = f"{RedisKeyType.PtUserNotifyNum.value}:{user_id}"
        redis_cli.hdel(name, notice_num_type)



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2020/7/23 16:33
:LastEditTime: 2020/7/23 16:33
:LastEditors: SunYiTan
:Description: Json帮助类
"""
import datetime
import decimal
import json


class JsonUtil:

    @staticmethod
    def dumps(obj):
        """
        :description: 对象 -> 字符串
        :param obj: 对象
        :return: 字符串
        :last_editors: SunYiTan
        """
        return json.dumps(obj, ensure_ascii=False, separators=(',', ':'), cls=MyJsonEncoder)


class MyJsonEncoder(json.JSONEncoder):
    """
    继承json.JSONEncoder

    使用方法:json.dumps(json_obj, ensure_ascii=False, cls=JsonEncoder)
    """

    def default(self, obj):  # pylint: disable=E0202
        if isinstance(obj, datetime.datetime):
            return obj.strftime('%Y-%m-%d %H:%M:%S')
        elif isinstance(obj, datetime.date):
            return obj.strftime("%Y-%m-%d")
        elif isinstance(obj, bytes):
            return obj.decode()
        elif isinstance(obj, decimal.Decimal):
            return str(decimal.Decimal(obj).quantize(decimal.Decimal('0.00')))
        else:
            # return json.JSONEncoder.default(self, obj)
            return obj.__dict__



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2020/7/22 16:13
:LastEditTime: 2020/7/22 16:13
:LastEditors: SunYiTan
:Description: 随机帮助类
"""

from bintrees import RBTree
import random


class RollHelp:

    def __init__(self):
        self.sum = 0
        self.rbTree = RBTree()

    def add_weight(self, odds, obj):
        self.sum += odds
        self.rbTree.insert(self.sum, obj)

    def get_roll(self):
        if self.sum > 0:
            rand = random.randint(1, self.sum)
            return self.rbTree.ceiling_item(rand)[1]

        else:
            return None




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PlatformUserThirdAuthModel(BaseModel):
    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformUserThirdAuthModel, self).__init__(PlatformUserThirdAuth, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PlatformUserThirdAuth:

    def __init__(self):
        super(PlatformUserThirdAuth, self).__init__()
        self.id = 0  # 自增id
        self.auth_id = 0  # 第三方验证唯一id
        self.channel = 0  # 第三方验证平台标识，0：NoSdk 1：QQ验证，2：微信验证
        self.app_id = ""  # 第三方app_id
        self.open_id = ""  # 第三方用户唯一标识
        self.union_channel = 0  # 开放平台标识，1：QQ互联
        self.union_id = ""  # 开放平台用户唯一标识符
        self.user_nick = ""  # 第三方用户昵称
        self.gender = 0  # 第三方用户性别，0：未知、1：男、2：女
        self.avatar = ""  # 第三方用户头像
        self.access_token = ""  # 第三方获取的access_token,校验使用
        self.app_channel = 0  # 注册时APP渠道标识，0：NoSdk 1：QQ小程序 2：微信小程序
        self.last_app_channel = 0  # 最近登录APP渠道标识，0：NoSdk 1：QQ小程序 2：微信小程序
        self.last_login_time = "1900-01-01 00:00:00"  # 上次登录时间
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'auth_id', 'channel', 'app_id', 'open_id', 'union_channel', 'union_id', 'user_nick', 'gender', 'avatar', 'access_token', 'app_channel', 'last_app_channel', 'last_login_time', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "platform_user_third_auth_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PlatformAssetInventoryModel(BaseModel):
    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformAssetInventoryModel, self).__init__(PlatformAssetInventory, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PlatformAssetInventory:

    def __init__(self):
        super(PlatformAssetInventory, self).__init__()
        self.id = 0  # id
        self.id_md5 = 0  # id_md5(act_id+user_id+asset_type+asset_object_id+create_day)md5int生成
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.user_nick = ""  # 用户昵称
        self.asset_type = 0  # 资产类型(1-次数2-积分3-价格档位)
        self.asset_object_id = ""  # 对象标识
        self.inc_value = 0  # 增加值
        self.dec_value = 0  # 消耗值
        self.history_value = 0  # 今天之前的资产值
        self.now_value = 0  # 当前的资产值
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.create_day = 0  # 创建时间天
        self.process_count = 0  # 处理次数
        self.process_date = "1900-01-01 00:00:00"  # 处理时间

    @classmethod
    def get_field_list(self):
        return ['id', 'id_md5', 'app_id', 'act_id', 'user_id', 'open_id', 'user_nick', 'asset_type', 'asset_object_id', 'inc_value', 'dec_value', 'history_value', 'now_value', 'create_date', 'create_day', 'process_count', 'process_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "platform_asset_inventory_tb"
    


# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2020/12/29 19:28
:LastEditTime: 2020/12/29 19:28
:LastEditors: SunYiTan
:Description: 玩家操作信息
"""


class ActionInfoVO:

    def __init__(self):
        self.action_id = 0
        self.doll_id = 0
        self.parama = ""
        self.paramb = ""
        self.paramc = ""
        self.paramd = ""



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/5/21 15:17
:LastEditTime: 2021/5/21 15:17
:LastEditors: SunYiTan
:Description: 用户统计日志表
"""
import decimal
import json

from seven_framework import TimeHelper

from seven_cmstar_platform.models.db_models.platform.platform_user_statistics_log_model import \
    PlatformUserStatisticsLogModel, PlatformUserStatisticsLog
from seven_cmstar_platform.models.enum import StatisticsOrmType, RedisKeyType
from seven_cmstar_platform.utils.json_util import JsonUtil
from seven_cmstar_platform.utils.redis_util import RedisUtil


class UserStatisticsLogModelEx(PlatformUserStatisticsLogModel):

    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)

    def add_log(self, user_id: int, third_auth_id: int, orm_id: int, inc_value):
        """
        添加记录
        :param user_id:
        :param third_auth_id
        :param orm_id:
        :param inc_value:
        :return:
        """
        now_date = TimeHelper.get_now_datetime()
        now_day = int(TimeHelper.datetime_to_format_time(now_date, "%Y%m%d"))
        now_hour = int(TimeHelper.datetime_to_format_time(now_date, "%Y%m%d%H"))

        statistics_log = self.get_entity(where="user_id=%s AND auth_id=%s AND orm_id=%s AND create_hour=%s",
                                         params=[user_id, third_auth_id, orm_id, now_hour])

        if statistics_log:
            self.update_table(update_sql="inc_value=inc_value+%s", where="id=%s",
                              params=[decimal.Decimal(inc_value), statistics_log.id])
        else:
            statistics_log = PlatformUserStatisticsLog()
            statistics_log.user_id = user_id
            statistics_log.auth_id = third_auth_id
            statistics_log.orm_id = orm_id
            statistics_log.inc_value = inc_value
            statistics_log.create_hour = now_hour
            statistics_log.create_day = now_day
            statistics_log.create_date = now_date

            self.add_entity(statistics_log)

    def record_remain_time(self, user_id):
        """
        统计用户留存时间
        :param user_id:
        :return:
        """
        now_time = TimeHelper.get_now_timestamp()
        key = f"{RedisKeyType.PtUserRemainTime.value}:{user_id}"

        result = RedisUtil().get(key)
        if not result:
            record_dict = {
                "record_time": now_time,
                "remain_time": 0
            }
            RedisUtil().set(key, JsonUtil.dumps(record_dict), 24 * 60 * 60)
            return

        record_dict = json.loads(result)
        if now_time - record_dict["record_time"] > 60:
            # 两协议间请求时间超过1分钟，重新开始统计
            remain_time = record_dict["remain_time"]
            record_dict = {
                "record_time": now_time,
                "remain_time": 0
            }
            RedisUtil().set(key, JsonUtil.dumps(record_dict), 24 * 60 * 60)

            if remain_time > 0:
                # 统计数据，记录之前累计的时间
                self.add_log(user_id, 0, StatisticsOrmType.RemainTime.value, remain_time)
        else:
            # 两协议间请求时间不超过1分钟，累计停留时间
            record_dict["remain_time"] += now_time - record_dict["record_time"]
            record_dict["record_time"] = now_time

            remain_time = record_dict["remain_time"]
            if remain_time >= 60:
                # 累计时间超过1分钟，记录时间，重新开始统计
                record_dict = {
                    "record_time": now_time,
                    "remain_time": 0
                }

                # 统计数据
                self.add_log(user_id, 0, StatisticsOrmType.RemainTime.value, remain_time)

            RedisUtil().set(key, JsonUtil.dumps(record_dict), 24 * 60 * 60)



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/5/14 17:01
:LastEditTime: 2021/5/14 17:01
:LastEditors: SunYiTan
:Description: 发放短信
"""
import logging

import baidubce.services.sms.sms_client as sms
import baidubce.exception as ex
from baidubce.auth.bce_credentials import BceCredentials
from baidubce.bce_client_configuration import BceClientConfiguration


class SmsHelper:

    def __init__(self, ak, sk, host):
        self.ak = ak
        self.sk = sk
        self.host = host

    def send_message(self, telephone: str, sms_sign, template_id, content_var_dict):
        """
        发送端口，百度云短信接口：https://cloud.baidu.com/doc/SMS/s/3kipnj5wy
        :param telephone: 手机号，多个手机号之间以英文逗号分隔，一次请求最多支持200个手机号
        :param code: 验证码
        :return:
        """
        try:
            sms_client = sms.SmsClient(BceClientConfiguration(credentials=BceCredentials(self.ak, self.sk),
                                                              endpoint=self.host))
            response = sms_client.send_message(signature_id=sms_sign,
                                               template_id=template_id,
                                               mobile=telephone,
                                               content_var_dict=content_var_dict)
            # print(JsonUtil.dumps(response))

            if response.code == "1000":
                return True
            else:
                logging.getLogger("log_error").error(f"send sms fail, code: {response.code}, msg: {response.message}")
                return False

        except ex.BceHttpClientError as e:
            if isinstance(e.last_error, ex.BceServerError):
                logging.getLogger("log_error").error('send sms failed. Response %s, code: %s, request_id: %s'
                                                     % (e.last_error.status_code, e.last_error.code,
                                                        e.last_error.request_id))
            else:
                logging.getLogger("log_error").error('send sms failed. Unknown exception: %s' % e)
            return False

        except Exception as e:
            logging.getLogger("log_error").error('send sms failed. Unknown exception: %s' % e)
            return False



# -*- coding: utf-8 -*-
"""
:Author: ChenXiaolei
:Date: 2020-12-07 19:12:00
:LastEditTime: 2020-12-08 18:31:50
:LastEditors: ChenXiaolei
:Description:
"""


class DictUtil:
    @classmethod
    def merge_dict_list(cls, source_dict_list, source_key, merge_dict_list, merge_key, merge_columns_names):
        """
        :description: 两个字典列表合并
        :param source_dict_list：源字典表
        :param source_key：源表用来关联的字段
        :param merge_dict_list：需要合并的字典表
        :param merge_key：需要合并的字典表用来关联的字段
        :param merge_columns_names：需要合并的字典表中需要展示的字段
        :return:
        :last_editors: HuangJingCan
        """
        result = []
        for source_dict in source_dict_list:
            info_list = [i for i in merge_dict_list if
                         source_dict[source_key] != "" and i[merge_key] == source_dict[source_key]]
            if info_list:
                list_key = list(merge_columns_names.split(","))
                source_dict = dict(source_dict, **dict.fromkeys(list_key))
                for item in list_key:
                    source_dict[item] = info_list[0].get(item)
            else:
                list1 = list(merge_columns_names.split(","))
                source_dict = dict(source_dict, **dict.fromkeys(list1))
            result.append(source_dict)
        return result

    @classmethod
    def auto_mapper(cls, model, map_dict=None):
        """
        :description: 对象映射（把map_dict值赋值到实体model中）
        :param model：需要映射的实体对象
        :param map_dict：被映射的实体字典
        :return: 映射后的实体model
        """
        if map_dict:
            field_list = model.get_field_list()
            for filed in field_list:
                if filed in map_dict:
                    setattr(model, filed, map_dict[filed])
        return model



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/11/15 15:38
:LastEditTime: 2021/11/15 15:38
:LastEditors: SunYiTan
:Description: 
"""
from seven_framework import MySQLHelper, config

from seven_cmstar_platform.models.cache_model import CacheModel
from seven_cmstar_platform.models.db_models.platform.platform_dict_info_model import PlatformDictInfo
from seven_cmstar_platform.models.enum import RedisKeyType


class PlatformDictInfoModelEx(CacheModel):
    __CACHE_KEY = RedisKeyType.PtDictInfo.value

    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformDictInfoModelEx, self).__init__(PlatformDictInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    @classmethod
    def get_dependency_key(self):
        return f"{self.__CACHE_KEY}"

    def get_dict_value(self, dict_id):
        """
        获取字典的值
        :param dict_id:
        :return:
        """
        dict_info = self.get_cache_dict(dependency_key=self.get_dependency_key(),
                                        where="dict_id=%s", params=[dict_id])
        if dict_info:
            return dict_info["dict_value"]
        else:
            return ""

    def get_dict_text(self, dict_id):
        """
        获取字典的值
        :param dict_id:
        :return:
        """
        dict_info = self.get_cache_dict(dependency_key=self.get_dependency_key(),
                                        where="dict_id=%s", params=[dict_id])
        if dict_info:
            return dict_info["dict_text"]
        else:
            return ""



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/9/27 14:03
:LastEditTime: 2021/9/27 14:03
:LastEditors: SunYiTan
:Description: 小程序帮助类
"""
import json
import logging
import sys

from seven_framework import config, HTTPHelper

from seven_cmstar_platform.handlers.qqmini_helper import QqMiniHelper
from seven_cmstar_platform.handlers.wxmini_helper import WxMiniHelper


class AppHelper:

    @classmethod
    def get_qq_access_token(cls, app_id):
        """
        获取qq access_token
        :param app_id:
        :return:
        """
        qq_mini_list = config.get_value("qq_mini")
        app_secret = ""
        for qq_info in qq_mini_list:
            if qq_info["app_id"] == app_id:
                app_secret = qq_info["app_secret"]
                break
        if not app_secret:
            logging.getLogger("log_error").error(f"获取QQ小程序信息失败，app_id: {app_id}")
            return True, ""

        access_token = None
        if "--production" in sys.argv:
            # 正式服
            access_token = QqMiniHelper.get_access_token_cache(app_id, app_secret)
        else:
            # 本地或测试服，请求正式服
            url = f"https://dollapps.idspub.com/platform/qq_access_token?app_id={app_id}" \
                  f"&app_secret={app_secret}"

            response = HTTPHelper.get(url)
            if response.status_code == 200:
                result = json.loads(response.text)
                if result["result"] == "0":
                    access_token = result["data"]

        return access_token

    @classmethod
    def get_wx_access_token(cls, app_id):
        """
        获取微信access_token
        :param app_id:
        :return:
        """
        qq_mini_list = config.get_value("wx_mini")
        app_secret = ""
        for qq_info in qq_mini_list:
            if qq_info["app_id"] == app_id:
                app_secret = qq_info["app_secret"]
                break
        if not app_secret:
            logging.getLogger("log_error").error(f"获取微信小程序信息失败，app_id: {app_id}")
            return ""

        access_token = None
        if "--production" in sys.argv:
            # 正式服
            access_token = WxMiniHelper.get_access_token_cache(app_id, app_secret)
        else:
            # 本地或测试服，请求正式服
            url = f"https://dollapps.idspub.com/platform/wx_access_token?app_id={app_id}" \
                  f"&app_secret={app_secret}"

            response = HTTPHelper.get(url)
            if response.status_code == 200:
                result = json.loads(response.text)
                if result["result"] == "0":
                    access_token = result["data"]

        return access_token

    @classmethod
    def get_wx_link_url(cl, app_id, path, query, env_version):
        """
        获取微信链接
        :param app_id:
        :param path:
        :param query:
        :param env_version: 要打开的小程序版本。正式版为"release"，体验版为"trial"，开发版为"develop"
        :return:
        """
        # 获取 access_token
        access_token = AppHelper.get_wx_access_token(app_id)
        if not access_token:
            logging.getLogger("log_error").error(f"get wx access token fail, app_id: {app_id}")
            return ""

        res = WxMiniHelper.generate_url_link(access_token, path, query, env_version)
        if res["errcode"] != 0:
            logging.getLogger("log_error").error(f"get wx url link fail, res: {res}")
            return ""

        return res["url_link"]

        # # 获取 scheme 码
        # res = WxMiniHelper.generate_scheme(access_token, path, query, env_version)
        # if res["errcode"] != 0:
        #     logging.getLogger("log_error").error(f"get wx scheme url fail, res: {res}")
        #     return ""
        #
        # # 长链接转成短链接
        # open_link = res["openlink"]
        # long_link = f"https://dollapps.idspub.com/redirect_scheme?t=gao7.com&scheme={CodingHelper.url_encode(open_link)}"
        # res = SevenHelper.long2short(long_link)
        # if res["ResultCode"] != "0":
        #     logging.getLogger("log_error").error(f"long2short fail, res: {res}")
        #     return ""
        #
        # wx_link_url = ""
        # for temp in res["Data"]:
        #     wx_link_url = temp["ShortUrl"]
        #
        # return wx_link_url

    @classmethod
    def qq_subscribe_message_send(cls, app_id, template_id, page_path, open_id, content):
        """
        发送订阅消息，qq
        :param app_id:
        :param template_id:
        :param page_path:
        :param open_id:
        :param content:
        :return:
        """
        # 获取 access_token
        access_token = cls.get_qq_access_token(app_id)
        if not access_token:
            logging.getLogger("log_error").error(f"get qq access token fail, app_id: {app_id}")
            return {"errcode": -1, "errmsg": "获取 access_token 失败"}

        return QqMiniHelper.subscribe_message_send(access_token, template_id, page_path, open_id, content)

    @classmethod
    def wx_uniform_message_send(cls, mp_appid, mp_template_id, app_id, page_path, open_id, content):
        """
        下发小程序和公众号统一的服务消息，微信
        :param mp_appid:
        :param mp_template_id:
        :param app_id:
        :param page_path:
        :param open_id:
        :param content:
        :return:
        """
        # 获取 access_token
        access_token = AppHelper.get_wx_access_token(app_id)
        if not access_token:
            logging.getLogger("log_error").error(f"get wx access token fail, app_id: {app_id}")
            return {"errcode": -1, "errmsg": "获取 access_token 失败"}

        return WxMiniHelper.uniform_message_send(access_token, mp_appid, mp_template_id, app_id, page_path, open_id,
                                                 content)




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PlatformUserStatisticsModel(BaseModel):
    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformUserStatisticsModel, self).__init__(PlatformUserStatistics, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PlatformUserStatistics:

    def __init__(self):
        super(PlatformUserStatistics, self).__init__()
        self.id = 0  # 自增id
        self.user_id = 0  # 玩家唯一id
        self.doll_num = 0  # 娃娃数
        self.cloth_num = 0  # 娃衣数
        self.post_num = 0  # 动态数
        self.comment_num = 0  # 评论数
        self.apply_num = 0  # 申请单
        self.quotation_num = 0  # 报价单
        self.order_num = 0  # 订单
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'user_id', 'doll_num', 'cloth_num', 'post_num', 'comment_num', 'apply_num', 'quotation_num', 'order_num', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "platform_user_statistics_tb"
    


# -*- coding:utf-8 -*-

from os import path as os_path
from setuptools import setup, find_packages

this_directory = os_path.abspath(os_path.dirname(__file__))


# 读取文件内容
def read_file(filename):
    with open(os_path.join(this_directory, filename)) as f:
        long_description = f.read()
    return long_description


# 获取依赖
def read_requirements(filename):
    return [line.strip() for line in read_file(filename).splitlines()
            if not line.startswith('#')]


setup(
    name='seven-cmstar-platform',  # 包名
    python_requires='~=3.4',  # python环境
    version='1.0.2.11',  # 包的版本
    description="seven cmstar platform",  # 包简介，显示在PyPI上
    long_description=read_file('README.md'),  # 读取的Readme文档内容
    long_description_content_type="text/markdown",  # 指定包文档格式为markdown
    author="seven",  # 作者相关信息
    author_email='tech@gao7.com',
    # url='http://geek.glodon.com/projects/BIGDATA/repos/cost_parser/browse',
    # 指定包信息，还可以用find_packages()函数
    packages=find_packages(),
    # package_data={
    #     'parser_code': ['metadata/shared/*.json']
    # },  # 读取需要的数据文件
    install_requires=read_requirements('requirements.txt'),  # 指定需要安装的依赖
    include_package_data=True,
    license="MIT",
    # keywords=['app'],
    classifiers=[
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9'
    ],
)




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PlatformBaseInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformBaseInfoModel, self).__init__(PlatformBaseInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PlatformBaseInfo:

    def __init__(self):
        super(PlatformBaseInfo, self).__init__()
        self.id = 0  # 自增id
        self.about_us = ""  # 关于我们
        self.customer_qq = ""  # 客服QQ
        self.customer_wechat = ""  # 客服微信
        self.novice_tid = 0  # 新手娃妈必看攻略话题id
        self.apply_course_tid = 0  # "如何提交【有效】咨询单"帖子话题id
        self.apply_course_pid = 0  # "如何提交【有效】咨询单"帖子id
        self.create_date = "1900-01-01 00:00:00"  # 创建时间，注册时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'about_us', 'customer_qq', 'customer_wechat', 'novice_tid', 'apply_course_tid', 'apply_course_pid', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "platform_base_info_tb"
    


# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/12/27 09:58
:LastEditTime: 2021/12/27 09:58
:LastEditors: SunYiTan
:Description: 
"""
from seven_cmstar_platform.models.enum import AppBaseRedisKeyType
from seven_cmstar_platform.utils.redis_util import RedisUtil
from seven_framework import UUIDHelper


class InviteModel():
    __USER_TOKEN_KEY = AppBaseRedisKeyType.InviteUserToken.value
    __TOKEN_USER_KEY = AppBaseRedisKeyType.InviteTokenUser.value

    @classmethod
    def __get_user_token(cls, user_id: int) -> str:
        """
        获取玩家token信息
        :param user_id:
        :return:
        """
        key1 = f"{cls.__USER_TOKEN_KEY}:{user_id}"
        return RedisUtil().get(key1)

    @classmethod
    def __update_user_token(cls, user_id: int, token: str):
        """
        更新玩家token信息
        :param user_id:
        :param token:
        :return:
        """
        key1 = f"{cls.__USER_TOKEN_KEY}:{user_id}"
        key2 = f"{cls.__TOKEN_USER_KEY}:{token}"
        RedisUtil().set(key1, token, 604800)  # 7天
        RedisUtil().set(key2, str(user_id), 604800)

    @classmethod
    def __get_user_id_by_token(cls, token: str):
        key2 = f"{cls.__TOKEN_USER_KEY}:{token}"
        s = RedisUtil().get(key2)
        if s:
            return int(s)
        else:
            return None

    @classmethod
    def get_invite_token(cls, user_id):
        """
        获取玩家邀请码
        :param user_id:
        :return:
        """
        token = cls.__get_user_token(user_id)
        if not token:
            token = UUIDHelper.get_uuid()

        cls.__update_user_token(user_id, token)
        return token

    @classmethod
    def get_user_id_by_token(cls, invite_token: str):
        """
        通过邀请码获取玩家id
        :param invite_token:
        :return:
        """
        if not invite_token:
            return None

        user_id = cls.__get_user_id_by_token(invite_token)
        return user_id



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/12/15 18:31
:LastEditTime: 2021/12/15 18:31
:LastEditors: SunYiTan
:Description: 
"""
from seven_cmstar_platform.models.asset_base_model import AssetBaseModel


class PlatformHelper:

    @classmethod
    def get_user_integral(self, user_id):
        """
        获取用户积分
        :param user_id: 用户唯一id
        :return: 用户当前积分
        """
        return AssetBaseModel(self).get_user_integral(user_id)

    @classmethod
    def update_user_integral(cls, user_id, asset_value,
                             source_type, source_object_id, source_object_name, log_title,
                             module_id=0, only_id="",
                             info_json=None):
        """
        :description: 变更用户积分
        :param user_id：用户唯一id
        :param asset_value：修改资产值
        :param source_type：来源类型（1-购买2-任务3-手动配置4-抽奖5-回购）
        :param source_object_id：来源对象标识(比如来源类型是任务则对应任务类型)
        :param source_object_name：来源对象名称(比如来源类型是任务则对应任务名称)
        :param log_title：资产流水标题
        :param module_id：模块标识，没有填0
        :param only_id:唯一标识(用于并发操作时校验避免重复操作)由业务方定义传入
        :param info_json：资产流水详情，用于存放业务方自定义字典
        :return: 返回实体InvokeResultData
        :last_editors: SunYiTan
        """
        return AssetBaseModel().update_user_integral(
            user_id, asset_value,
            source_type, source_object_id, source_object_name, log_title, module_id, only_id, info_json)



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PlatformDollInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformDollInfoModel, self).__init__(PlatformDollInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PlatformDollInfo:

    def __init__(self):
        super(PlatformDollInfo, self).__init__()
        self.id = 0  # 自增id
        self.doll_id = 0  # 娃娃唯一id
        self.doll_code = ""  # 娃娃编号
        self.cdk = ""  # 对应的激活码
        self.order_id = 0  # 订单唯一id
        self.market_order_id = 0  # 商城订单id
        self.market_order_goods_id = 0  # 商城订单商品id
        self.goods_id = 0  # 娃类唯一id
        self.goods_code = ""  # 娃类编码
        self.seller_id = 0  # 卖家唯一id
        self.doll_nick = ""  # 娃娃昵称
        self.gender = 0  # 性别
        self.height = ""  # 娃娃身高
        self.telephone = ""  # 绑定的手机号
        self.qq = ""  # 绑定的QQ号
        self.birth_date = "1900-01-01 00:00:00"  # 出生时间
        self.activate_date = "1900-01-01 00:00:00"  # 激活时间
        self.activate_user_id = 0  # 激活的玩家id
        self.user_id = 0  # 拥有的玩家id，娃妈id
        self.get_type = 0  # 获得类型，1购买获得，2系统赠送，3奖励获得，4转让获得
        self.got_cloth = 0  # 是否已经领取过服饰
        self.activate_sort = 0  # 激活序号
        self.doll_type = 0  # 娃娃类型，1永久，2限时
        self.is_equipped_cloth = 0  # 是否穿戴衣服
        self.cms_user_id = ""  # 操作用户id
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间
        self.expire_date = "1900-01-01 00:00:00"  # 过期时间

    @classmethod
    def get_field_list(self):
        return ['id', 'doll_id', 'doll_code', 'cdk', 'order_id', 'market_order_id', 'market_order_goods_id', 'goods_id', 'goods_code', 'seller_id', 'doll_nick', 'gender', 'height', 'telephone', 'qq', 'birth_date', 'activate_date', 'activate_user_id', 'user_id', 'get_type', 'got_cloth', 'activate_sort', 'doll_type', 'is_equipped_cloth', 'cms_user_id', 'create_date', 'modify_date', 'expire_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "platform_doll_info_tb"
    


# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/11/11 18:40
:LastEditTime: 2021/11/11 18:40
:LastEditors: SunYiTan
:Description: 
"""
import decimal

from seven_framework import TimeHelper, CryptoHelper, MySQLHelper, config

from seven_cmstar_platform.models.cache_model import CacheModel
from seven_cmstar_platform.models.db_models.platform.platform_search_statistics_log_model import \
    PlatformSearchStatisticsLog
from seven_cmstar_platform.models.enum import RedisKeyType


class SearchStatisticsLogModelEx(CacheModel):
    __CACHE_KEY = RedisKeyType.PtSearchStatisticsLog.value

    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(SearchStatisticsLogModelEx, self).__init__(PlatformSearchStatisticsLog, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    @classmethod
    def get_dependency_key(self):
        return f"{self.__CACHE_KEY}"

    def add_log(self, keyword, inc_value):
        """
        添加记录
        :param keyword:
        :param inc_value:
        :return:
        """
        if not keyword:
            return

        keyword_id = CryptoHelper.md5_encrypt_int(keyword)
        now_date = TimeHelper.get_now_datetime()
        now_day = int(TimeHelper.datetime_to_format_time(now_date, "%Y%m%d"))

        statistics_log = self.get_entity(where="keyword_id=%s AND create_day=%s",
                                         params=[keyword_id, now_day])

        if statistics_log:
            self.update_table(update_sql="inc_value=inc_value+%s", where="id=%s",
                              params=[decimal.Decimal(inc_value), statistics_log.id])
        else:
            statistics_log = PlatformSearchStatisticsLog()
            statistics_log.keyword_id = keyword_id
            statistics_log.keyword = keyword
            statistics_log.inc_value = inc_value
            statistics_log.create_day = now_day
            statistics_log.create_date = now_date

            self.add_entity(statistics_log)



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2020/7/21 10:50
:LastEditTime: 2020/7/21 10:50
:LastEditors: SunYiTan
:Description: redis工具类
"""

import redis
import time
import uuid
import math

from seven_framework import config


class RedisUtil(object):

    def __init__(self):
        if not hasattr(RedisUtil, 'pool'):
            # 创建redis连接池
            RedisUtil.get_redis_pool()
        self.conn = redis.Redis(connection_pool=RedisUtil.pool)

    @staticmethod
    def get_redis_pool():
        host = config.get_value("redis")["host"]
        port = config.get_value("redis")["port"]
        db = config.get_value("redis")["db"]
        password = config.get_value("redis")["password"]
        RedisUtil.pool = redis.ConnectionPool(host=host, password=password,
                                              port=port, db=db, decode_responses=True)

    #################################### str ######################################

    def set(self, key, value, time=None):
        # 非空即真非0即真
        if time:
            res = self.conn.setex(key, time, value)
        else:
            res = self.conn.set(key, value)
        return res

    def get(self, key):
        res = self.conn.get(key)
        if res:
            res = res
        return res

    def delete(self, key):
        return self.conn.delete(key)

    def incr(self, key, amount=1):
        return self.conn.incr(key, amount)

    #################################### hash ######################################

    def hset(self, name, key, value):
        return self.conn.hset(name, key, value)

    def hsetnx(self, name, key, value):
        return self.conn.hsetnx(name, key, value)

    def expire(self, name, time):
        return self.conn.expire(name, time)

    def hget(self, name, key=None):
        # 判断key是否我为空，不为空，获取指定name内的某个key的value; 为空则获取name对应的所有value
        if key:
            res = self.conn.hget(name, key)
        else:
            res = self.conn.hgetall(name)
        return res

    def hdel(self, name, key):
        return self.conn.hdel(name, key)

    def hincrby(self, name, key, amount=1):
        return self.conn.hincrby(name, key, amount)

    def hexists(self, name, key):
        return self.conn.hexists(name, key)

    def hvals(self, name):
        return self.conn.hvals(name)

    def hkeys(self, name):
        return self.conn.hkeys(name)

    #################################### 列表 ######################################

    def lpush(self, key: str, value: str, max_num: int):
        """
        :description: 列表，lpush方法，保留一定条数
        :last_editors: SunYiTan
        """
        self.conn.lpush(key, value)
        if max_num:
            self.conn.ltrim(key, 0, max_num - 1)

    def lindex(self, key: str, index: int) -> str:
        """
        :description: 列表，lindex方法
        :last_editors: SunYiTan
        """
        return self.conn.lindex(key, index)

    def lrange(self, key: str, start: int, stop: int):
        """
        :description: 列表，lrange方法
        :last_editors: SunYiTan
        """
        return self.conn.lrange(key, start, stop)

    def llen(self, key: str):
        """
        :description: 列表，llen方法
        :last_editors: SunYiTan
        """
        return self.conn.llen(key)

    #################################### 有序集合 ######################################

    def zadd(self, key: str, score: int, member: str, max_rank: int):
        """
        :description: 有序集合，zadd方法，保留一定条数
        :last_editors: SunYiTan
        """
        self.conn.zadd(key, {member: score})
        self.conn.zremrangebyrank(key, 0, -max_rank)

    def zrem(self, key: str, member: str):
        """
        :description: 有序集合，zrem方法
        :last_editors: SunYiTan
        """
        self.conn.zrem(key, member)

    def zrevrank(self, key: str, member: str) -> int:
        """
        :description: 有序集合，zrevrank方法
        :last_editors: SunYiTan
        """
        return self.conn.zrevrank(key, member)

    def zscore(self, key: str, member: str):
        """
        :description: 有序集合，zscore方法。返回有序集 key 中，成员 member 的 score 值。
        :last_editors: SunYiTan
        """
        return self.conn.zscore(key, member)

    def zrevrangeWithScores(self, key: str, min: int, max: int):
        """
        :description: 有序集合，zrevrangeWithScores方法
        :last_editors: SunYiTan
        """
        return self.conn.zrevrange(key, min, max, withscores=True)

    #################################### 分布式锁 ######################################

    def acquire_lock_with_timeout(self, lock_name, acquire_timeout=10, lock_timeout=9):
        """ 基于 Redis 实现的分布式锁

        :param lock_name: 锁的名称
        :param acquire_timeout: 获取锁的超时时间，默认 10 秒
        :param lock_timeout: 锁的超时时间，默认 9 秒
        :return:
        """

        identifier = str(uuid.uuid4())
        lockname = f'lock:{lock_name}'
        lock_timeout = int(math.ceil(lock_timeout))
        end = time.time() + acquire_timeout

        while time.time() < end:
            # 如果不存在这个锁则加锁并设置过期时间，避免死锁
            if self.conn.set(lockname, identifier, ex=lock_timeout, nx=True):
                return identifier

            time.sleep(0.001)

        return None

    def release_lock(self, lock_name, identifier):
        """ 释放锁

        :param conn: Redis 连接
        :param lockname: 锁的名称
        :param identifier: 锁的标识
        :return:
        """

        unlock_script = """
        if redis.call("get",KEYS[1]) == ARGV[1] then
            return redis.call("del",KEYS[1])
        else
            return 0
        end
        """
        lockname = f'lock:{lock_name}'
        unlock = self.conn.register_script(unlock_script)
        result = unlock(keys=[lockname], args=[identifier])
        if result:
            return True
        else:
            return False

    def can_pass_token_bucket(self, key, current_time, interval_per_token, max_token=10, init_token=10):
        """
        限流，令牌桶法
        :param key:
        :param current_time: 当前请求时间 ms
        :param interval_per_token: 每个令牌之间的间隔
        :param max_token: 桶内最大的令牌数量
        :param init_token: 初始的令牌数量
        :return:
        """
        limit_script = """
            local key = KEYS[1]
            local currentTime = tonumber(ARGV[1])
            local intervalPerToken = tonumber(ARGV[2])
            local maxToken = tonumber(ARGV[3])
            local initToken = tonumber(ARGV[4])
            local maxInterval = tonumber(ARGV[5])
            local tokens
            local bucket = redis.call("hmget", key, "lastTime", "lastToken")
            local lastTime = bucket[1]
            local lastToken = bucket[2]
            if lastTime == false or lastToken == false then
                tokens = initToken
                lastTime = currentTime
            else
                local thisInterval = currentTime - lastTime
                if thisInterval > 0 then
                    local tokensToAdd = math.floor(thisInterval / intervalPerToken)
                    tokens = math.min(lastToken + tokensToAdd, maxToken)
                    lastTime = lastTime + intervalPerToken * tokensToAdd
                else
                    tokens = lastToken
                    lastTime = lastTime
                end
            end
            if tokens == 0 then
                redis.call('hmset', key, 'lastToken', tokens, "lastTime", lastTime)
                redis.call('expire', key, 60 * 60)
                return false
            else
                redis.call('hmset', key, 'lastToken', tokens - 1, "lastTime", lastTime)
                redis.call('expire', key, 60 * 60)
                return true
            end
            """
        limit_key = f'limit:{key}'
        can_pass = self.conn.register_script(limit_script)
        return can_pass(keys=[limit_key], args=[current_time, interval_per_token, max_token, init_token])



# -*- coding:utf-8 -*-
"""
:Author: SunYiTan
:Date: 2021/5/21 15:17
:LastEditTime: 2021/5/21 15:17
:LastEditors: SunYiTan
:Description: 
"""
from seven_framework import TimeHelper

from seven_cmstar_platform.models.db_models.ezgame.ezgame_user_action_log_model import EzgameUserActionLogModel, EzgameUserActionLog
from seven_cmstar_platform.models.action_log_model import ActionInfoVO


class UserActionLogModelEx(EzgameUserActionLogModel):

    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super().__init__(db_connect_key, sub_table, db_transaction, context)

    def write_log(self, user_id: int, action_info_vo: ActionInfoVO):
        action_log = EzgameUserActionLog()
        action_log.user_id = user_id
        action_log.action_id = action_info_vo.action_id
        action_log.doll_id = action_info_vo.doll_id
        action_log.parama = action_info_vo.parama
        action_log.paramb = action_info_vo.paramb
        action_log.paramc = action_info_vo.paramc
        action_log.paramd = action_info_vo.paramd
        action_log.create_date = TimeHelper.get_now_datetime()

        self.add_entity(action_log)




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PlatformUserInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_platform', sub_table=None, db_transaction=None, context=None):
        super(PlatformUserInfoModel, self).__init__(PlatformUserInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PlatformUserInfo:

    def __init__(self):
        super(PlatformUserInfo, self).__init__()
        self.id = 0  # 自增id
        self.user_id = 0  # 玩家唯一id
        self.telephone = ""  # 绑定的手机号
        self.user_nick = ""  # 用户昵称
        self.gender = 0  # 性别
        self.avatar = ""  # 头像
        self.sign = ""  # 用户签名
        self.inviter_id = 0  # 邀请者Id
        self.tags = ""  # 标签列表，1娃妈 2娃太 3画手
        self.qq = ""  # QQ号
        self.wechat = ""  # 微信号
        self.mail = ""  # 邮箱号
        self.birthday = ""  # 生日
        self.status = 0  # 状态，0正常 1冻结
        self.freeze_reason = ""  # 账号冻结原因
        self.freeze_type = 0  # 冻结类型，1-1天，2-1周，3-一月，4-一年，5-永久
        self.freeze_begin_date = "1900-01-01 00:00:00"  # 冻结开始时间
        self.freeze_end_date = "1900-01-01 00:00:00"  # 冻结结束时间
        self.register_channel = 0  # 注册渠道，第三方平台标识，1QQ小程序（字段废弃）
        self.app_channel = 0  # 注册时APP渠道标识，0：NoSdk 1：QQ小程序 2：微信小程序
        self.last_app_channel = 0  # 最近登录APP渠道标识，0：NoSdk 1：QQ小程序 2：微信小程序
        self.last_login_time = "1900-01-01 00:00:00"  # 上次登录时间
        self.check_fans_date = "1900-01-01 00:00:00"  # 上次查看粉丝时间
        self.del_status = 0  # 注销状态，0正常，1注销中，2已注销
        self.del_begin_at = 0  # 注销开始时间戳
        self.del_end_at = 0  # 注销完成时间戳
        self.im_status = 0  # IM状态，0未注册，1已注册
        self.user_type = 0  # 用户类型，0：普通用户，100：运营人员
        self.create_date = "1900-01-01 00:00:00"  # 创建时间，注册时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间
        self.modify_phone_date = "1900-01-01 00:00:00"  # 修改手机时间

    @classmethod
    def get_field_list(self):
        return ['id', 'user_id', 'telephone', 'user_nick', 'gender', 'avatar', 'sign', 'inviter_id', 'tags', 'qq', 'wechat', 'mail', 'birthday', 'status', 'freeze_reason', 'freeze_type', 'freeze_begin_date', 'freeze_end_date', 'register_channel', 'app_channel', 'last_app_channel', 'last_login_time', 'check_fans_date', 'del_status', 'del_begin_at', 'del_end_at', 'im_status', 'user_type', 'create_date', 'modify_date', 'modify_phone_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "platform_user_info_tb"
    